// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RDLOW_RNLOW_OPERAND_IMMEDIATE_ZERO_IN_IT_BLOCK_RSB_T32_H_
#define VIXL_ASSEMBLER_COND_RDLOW_RNLOW_OPERAND_IMMEDIATE_ZERO_IN_IT_BLOCK_RSB_T32_H_

const byte kInstruction_rsb_eq_r0_r0_0[] = {
  0x08, 0xbf, 0x40, 0x42 // It eq; rsb eq r0 r0 0
};
const byte kInstruction_rsb_eq_r0_r1_0[] = {
  0x08, 0xbf, 0x48, 0x42 // It eq; rsb eq r0 r1 0
};
const byte kInstruction_rsb_eq_r0_r2_0[] = {
  0x08, 0xbf, 0x50, 0x42 // It eq; rsb eq r0 r2 0
};
const byte kInstruction_rsb_eq_r0_r3_0[] = {
  0x08, 0xbf, 0x58, 0x42 // It eq; rsb eq r0 r3 0
};
const byte kInstruction_rsb_eq_r0_r4_0[] = {
  0x08, 0xbf, 0x60, 0x42 // It eq; rsb eq r0 r4 0
};
const byte kInstruction_rsb_eq_r0_r5_0[] = {
  0x08, 0xbf, 0x68, 0x42 // It eq; rsb eq r0 r5 0
};
const byte kInstruction_rsb_eq_r0_r6_0[] = {
  0x08, 0xbf, 0x70, 0x42 // It eq; rsb eq r0 r6 0
};
const byte kInstruction_rsb_eq_r0_r7_0[] = {
  0x08, 0xbf, 0x78, 0x42 // It eq; rsb eq r0 r7 0
};
const byte kInstruction_rsb_eq_r1_r0_0[] = {
  0x08, 0xbf, 0x41, 0x42 // It eq; rsb eq r1 r0 0
};
const byte kInstruction_rsb_eq_r1_r1_0[] = {
  0x08, 0xbf, 0x49, 0x42 // It eq; rsb eq r1 r1 0
};
const byte kInstruction_rsb_eq_r1_r2_0[] = {
  0x08, 0xbf, 0x51, 0x42 // It eq; rsb eq r1 r2 0
};
const byte kInstruction_rsb_eq_r1_r3_0[] = {
  0x08, 0xbf, 0x59, 0x42 // It eq; rsb eq r1 r3 0
};
const byte kInstruction_rsb_eq_r1_r4_0[] = {
  0x08, 0xbf, 0x61, 0x42 // It eq; rsb eq r1 r4 0
};
const byte kInstruction_rsb_eq_r1_r5_0[] = {
  0x08, 0xbf, 0x69, 0x42 // It eq; rsb eq r1 r5 0
};
const byte kInstruction_rsb_eq_r1_r6_0[] = {
  0x08, 0xbf, 0x71, 0x42 // It eq; rsb eq r1 r6 0
};
const byte kInstruction_rsb_eq_r1_r7_0[] = {
  0x08, 0xbf, 0x79, 0x42 // It eq; rsb eq r1 r7 0
};
const byte kInstruction_rsb_eq_r2_r0_0[] = {
  0x08, 0xbf, 0x42, 0x42 // It eq; rsb eq r2 r0 0
};
const byte kInstruction_rsb_eq_r2_r1_0[] = {
  0x08, 0xbf, 0x4a, 0x42 // It eq; rsb eq r2 r1 0
};
const byte kInstruction_rsb_eq_r2_r2_0[] = {
  0x08, 0xbf, 0x52, 0x42 // It eq; rsb eq r2 r2 0
};
const byte kInstruction_rsb_eq_r2_r3_0[] = {
  0x08, 0xbf, 0x5a, 0x42 // It eq; rsb eq r2 r3 0
};
const byte kInstruction_rsb_eq_r2_r4_0[] = {
  0x08, 0xbf, 0x62, 0x42 // It eq; rsb eq r2 r4 0
};
const byte kInstruction_rsb_eq_r2_r5_0[] = {
  0x08, 0xbf, 0x6a, 0x42 // It eq; rsb eq r2 r5 0
};
const byte kInstruction_rsb_eq_r2_r6_0[] = {
  0x08, 0xbf, 0x72, 0x42 // It eq; rsb eq r2 r6 0
};
const byte kInstruction_rsb_eq_r2_r7_0[] = {
  0x08, 0xbf, 0x7a, 0x42 // It eq; rsb eq r2 r7 0
};
const byte kInstruction_rsb_eq_r3_r0_0[] = {
  0x08, 0xbf, 0x43, 0x42 // It eq; rsb eq r3 r0 0
};
const byte kInstruction_rsb_eq_r3_r1_0[] = {
  0x08, 0xbf, 0x4b, 0x42 // It eq; rsb eq r3 r1 0
};
const byte kInstruction_rsb_eq_r3_r2_0[] = {
  0x08, 0xbf, 0x53, 0x42 // It eq; rsb eq r3 r2 0
};
const byte kInstruction_rsb_eq_r3_r3_0[] = {
  0x08, 0xbf, 0x5b, 0x42 // It eq; rsb eq r3 r3 0
};
const byte kInstruction_rsb_eq_r3_r4_0[] = {
  0x08, 0xbf, 0x63, 0x42 // It eq; rsb eq r3 r4 0
};
const byte kInstruction_rsb_eq_r3_r5_0[] = {
  0x08, 0xbf, 0x6b, 0x42 // It eq; rsb eq r3 r5 0
};
const byte kInstruction_rsb_eq_r3_r6_0[] = {
  0x08, 0xbf, 0x73, 0x42 // It eq; rsb eq r3 r6 0
};
const byte kInstruction_rsb_eq_r3_r7_0[] = {
  0x08, 0xbf, 0x7b, 0x42 // It eq; rsb eq r3 r7 0
};
const byte kInstruction_rsb_eq_r4_r0_0[] = {
  0x08, 0xbf, 0x44, 0x42 // It eq; rsb eq r4 r0 0
};
const byte kInstruction_rsb_eq_r4_r1_0[] = {
  0x08, 0xbf, 0x4c, 0x42 // It eq; rsb eq r4 r1 0
};
const byte kInstruction_rsb_eq_r4_r2_0[] = {
  0x08, 0xbf, 0x54, 0x42 // It eq; rsb eq r4 r2 0
};
const byte kInstruction_rsb_eq_r4_r3_0[] = {
  0x08, 0xbf, 0x5c, 0x42 // It eq; rsb eq r4 r3 0
};
const byte kInstruction_rsb_eq_r4_r4_0[] = {
  0x08, 0xbf, 0x64, 0x42 // It eq; rsb eq r4 r4 0
};
const byte kInstruction_rsb_eq_r4_r5_0[] = {
  0x08, 0xbf, 0x6c, 0x42 // It eq; rsb eq r4 r5 0
};
const byte kInstruction_rsb_eq_r4_r6_0[] = {
  0x08, 0xbf, 0x74, 0x42 // It eq; rsb eq r4 r6 0
};
const byte kInstruction_rsb_eq_r4_r7_0[] = {
  0x08, 0xbf, 0x7c, 0x42 // It eq; rsb eq r4 r7 0
};
const byte kInstruction_rsb_eq_r5_r0_0[] = {
  0x08, 0xbf, 0x45, 0x42 // It eq; rsb eq r5 r0 0
};
const byte kInstruction_rsb_eq_r5_r1_0[] = {
  0x08, 0xbf, 0x4d, 0x42 // It eq; rsb eq r5 r1 0
};
const byte kInstruction_rsb_eq_r5_r2_0[] = {
  0x08, 0xbf, 0x55, 0x42 // It eq; rsb eq r5 r2 0
};
const byte kInstruction_rsb_eq_r5_r3_0[] = {
  0x08, 0xbf, 0x5d, 0x42 // It eq; rsb eq r5 r3 0
};
const byte kInstruction_rsb_eq_r5_r4_0[] = {
  0x08, 0xbf, 0x65, 0x42 // It eq; rsb eq r5 r4 0
};
const byte kInstruction_rsb_eq_r5_r5_0[] = {
  0x08, 0xbf, 0x6d, 0x42 // It eq; rsb eq r5 r5 0
};
const byte kInstruction_rsb_eq_r5_r6_0[] = {
  0x08, 0xbf, 0x75, 0x42 // It eq; rsb eq r5 r6 0
};
const byte kInstruction_rsb_eq_r5_r7_0[] = {
  0x08, 0xbf, 0x7d, 0x42 // It eq; rsb eq r5 r7 0
};
const byte kInstruction_rsb_eq_r6_r0_0[] = {
  0x08, 0xbf, 0x46, 0x42 // It eq; rsb eq r6 r0 0
};
const byte kInstruction_rsb_eq_r6_r1_0[] = {
  0x08, 0xbf, 0x4e, 0x42 // It eq; rsb eq r6 r1 0
};
const byte kInstruction_rsb_eq_r6_r2_0[] = {
  0x08, 0xbf, 0x56, 0x42 // It eq; rsb eq r6 r2 0
};
const byte kInstruction_rsb_eq_r6_r3_0[] = {
  0x08, 0xbf, 0x5e, 0x42 // It eq; rsb eq r6 r3 0
};
const byte kInstruction_rsb_eq_r6_r4_0[] = {
  0x08, 0xbf, 0x66, 0x42 // It eq; rsb eq r6 r4 0
};
const byte kInstruction_rsb_eq_r6_r5_0[] = {
  0x08, 0xbf, 0x6e, 0x42 // It eq; rsb eq r6 r5 0
};
const byte kInstruction_rsb_eq_r6_r6_0[] = {
  0x08, 0xbf, 0x76, 0x42 // It eq; rsb eq r6 r6 0
};
const byte kInstruction_rsb_eq_r6_r7_0[] = {
  0x08, 0xbf, 0x7e, 0x42 // It eq; rsb eq r6 r7 0
};
const byte kInstruction_rsb_eq_r7_r0_0[] = {
  0x08, 0xbf, 0x47, 0x42 // It eq; rsb eq r7 r0 0
};
const byte kInstruction_rsb_eq_r7_r1_0[] = {
  0x08, 0xbf, 0x4f, 0x42 // It eq; rsb eq r7 r1 0
};
const byte kInstruction_rsb_eq_r7_r2_0[] = {
  0x08, 0xbf, 0x57, 0x42 // It eq; rsb eq r7 r2 0
};
const byte kInstruction_rsb_eq_r7_r3_0[] = {
  0x08, 0xbf, 0x5f, 0x42 // It eq; rsb eq r7 r3 0
};
const byte kInstruction_rsb_eq_r7_r4_0[] = {
  0x08, 0xbf, 0x67, 0x42 // It eq; rsb eq r7 r4 0
};
const byte kInstruction_rsb_eq_r7_r5_0[] = {
  0x08, 0xbf, 0x6f, 0x42 // It eq; rsb eq r7 r5 0
};
const byte kInstruction_rsb_eq_r7_r6_0[] = {
  0x08, 0xbf, 0x77, 0x42 // It eq; rsb eq r7 r6 0
};
const byte kInstruction_rsb_eq_r7_r7_0[] = {
  0x08, 0xbf, 0x7f, 0x42 // It eq; rsb eq r7 r7 0
};
const byte kInstruction_rsb_ne_r0_r0_0[] = {
  0x18, 0xbf, 0x40, 0x42 // It ne; rsb ne r0 r0 0
};
const byte kInstruction_rsb_ne_r0_r1_0[] = {
  0x18, 0xbf, 0x48, 0x42 // It ne; rsb ne r0 r1 0
};
const byte kInstruction_rsb_ne_r0_r2_0[] = {
  0x18, 0xbf, 0x50, 0x42 // It ne; rsb ne r0 r2 0
};
const byte kInstruction_rsb_ne_r0_r3_0[] = {
  0x18, 0xbf, 0x58, 0x42 // It ne; rsb ne r0 r3 0
};
const byte kInstruction_rsb_ne_r0_r4_0[] = {
  0x18, 0xbf, 0x60, 0x42 // It ne; rsb ne r0 r4 0
};
const byte kInstruction_rsb_ne_r0_r5_0[] = {
  0x18, 0xbf, 0x68, 0x42 // It ne; rsb ne r0 r5 0
};
const byte kInstruction_rsb_ne_r0_r6_0[] = {
  0x18, 0xbf, 0x70, 0x42 // It ne; rsb ne r0 r6 0
};
const byte kInstruction_rsb_ne_r0_r7_0[] = {
  0x18, 0xbf, 0x78, 0x42 // It ne; rsb ne r0 r7 0
};
const byte kInstruction_rsb_ne_r1_r0_0[] = {
  0x18, 0xbf, 0x41, 0x42 // It ne; rsb ne r1 r0 0
};
const byte kInstruction_rsb_ne_r1_r1_0[] = {
  0x18, 0xbf, 0x49, 0x42 // It ne; rsb ne r1 r1 0
};
const byte kInstruction_rsb_ne_r1_r2_0[] = {
  0x18, 0xbf, 0x51, 0x42 // It ne; rsb ne r1 r2 0
};
const byte kInstruction_rsb_ne_r1_r3_0[] = {
  0x18, 0xbf, 0x59, 0x42 // It ne; rsb ne r1 r3 0
};
const byte kInstruction_rsb_ne_r1_r4_0[] = {
  0x18, 0xbf, 0x61, 0x42 // It ne; rsb ne r1 r4 0
};
const byte kInstruction_rsb_ne_r1_r5_0[] = {
  0x18, 0xbf, 0x69, 0x42 // It ne; rsb ne r1 r5 0
};
const byte kInstruction_rsb_ne_r1_r6_0[] = {
  0x18, 0xbf, 0x71, 0x42 // It ne; rsb ne r1 r6 0
};
const byte kInstruction_rsb_ne_r1_r7_0[] = {
  0x18, 0xbf, 0x79, 0x42 // It ne; rsb ne r1 r7 0
};
const byte kInstruction_rsb_ne_r2_r0_0[] = {
  0x18, 0xbf, 0x42, 0x42 // It ne; rsb ne r2 r0 0
};
const byte kInstruction_rsb_ne_r2_r1_0[] = {
  0x18, 0xbf, 0x4a, 0x42 // It ne; rsb ne r2 r1 0
};
const byte kInstruction_rsb_ne_r2_r2_0[] = {
  0x18, 0xbf, 0x52, 0x42 // It ne; rsb ne r2 r2 0
};
const byte kInstruction_rsb_ne_r2_r3_0[] = {
  0x18, 0xbf, 0x5a, 0x42 // It ne; rsb ne r2 r3 0
};
const byte kInstruction_rsb_ne_r2_r4_0[] = {
  0x18, 0xbf, 0x62, 0x42 // It ne; rsb ne r2 r4 0
};
const byte kInstruction_rsb_ne_r2_r5_0[] = {
  0x18, 0xbf, 0x6a, 0x42 // It ne; rsb ne r2 r5 0
};
const byte kInstruction_rsb_ne_r2_r6_0[] = {
  0x18, 0xbf, 0x72, 0x42 // It ne; rsb ne r2 r6 0
};
const byte kInstruction_rsb_ne_r2_r7_0[] = {
  0x18, 0xbf, 0x7a, 0x42 // It ne; rsb ne r2 r7 0
};
const byte kInstruction_rsb_ne_r3_r0_0[] = {
  0x18, 0xbf, 0x43, 0x42 // It ne; rsb ne r3 r0 0
};
const byte kInstruction_rsb_ne_r3_r1_0[] = {
  0x18, 0xbf, 0x4b, 0x42 // It ne; rsb ne r3 r1 0
};
const byte kInstruction_rsb_ne_r3_r2_0[] = {
  0x18, 0xbf, 0x53, 0x42 // It ne; rsb ne r3 r2 0
};
const byte kInstruction_rsb_ne_r3_r3_0[] = {
  0x18, 0xbf, 0x5b, 0x42 // It ne; rsb ne r3 r3 0
};
const byte kInstruction_rsb_ne_r3_r4_0[] = {
  0x18, 0xbf, 0x63, 0x42 // It ne; rsb ne r3 r4 0
};
const byte kInstruction_rsb_ne_r3_r5_0[] = {
  0x18, 0xbf, 0x6b, 0x42 // It ne; rsb ne r3 r5 0
};
const byte kInstruction_rsb_ne_r3_r6_0[] = {
  0x18, 0xbf, 0x73, 0x42 // It ne; rsb ne r3 r6 0
};
const byte kInstruction_rsb_ne_r3_r7_0[] = {
  0x18, 0xbf, 0x7b, 0x42 // It ne; rsb ne r3 r7 0
};
const byte kInstruction_rsb_ne_r4_r0_0[] = {
  0x18, 0xbf, 0x44, 0x42 // It ne; rsb ne r4 r0 0
};
const byte kInstruction_rsb_ne_r4_r1_0[] = {
  0x18, 0xbf, 0x4c, 0x42 // It ne; rsb ne r4 r1 0
};
const byte kInstruction_rsb_ne_r4_r2_0[] = {
  0x18, 0xbf, 0x54, 0x42 // It ne; rsb ne r4 r2 0
};
const byte kInstruction_rsb_ne_r4_r3_0[] = {
  0x18, 0xbf, 0x5c, 0x42 // It ne; rsb ne r4 r3 0
};
const byte kInstruction_rsb_ne_r4_r4_0[] = {
  0x18, 0xbf, 0x64, 0x42 // It ne; rsb ne r4 r4 0
};
const byte kInstruction_rsb_ne_r4_r5_0[] = {
  0x18, 0xbf, 0x6c, 0x42 // It ne; rsb ne r4 r5 0
};
const byte kInstruction_rsb_ne_r4_r6_0[] = {
  0x18, 0xbf, 0x74, 0x42 // It ne; rsb ne r4 r6 0
};
const byte kInstruction_rsb_ne_r4_r7_0[] = {
  0x18, 0xbf, 0x7c, 0x42 // It ne; rsb ne r4 r7 0
};
const byte kInstruction_rsb_ne_r5_r0_0[] = {
  0x18, 0xbf, 0x45, 0x42 // It ne; rsb ne r5 r0 0
};
const byte kInstruction_rsb_ne_r5_r1_0[] = {
  0x18, 0xbf, 0x4d, 0x42 // It ne; rsb ne r5 r1 0
};
const byte kInstruction_rsb_ne_r5_r2_0[] = {
  0x18, 0xbf, 0x55, 0x42 // It ne; rsb ne r5 r2 0
};
const byte kInstruction_rsb_ne_r5_r3_0[] = {
  0x18, 0xbf, 0x5d, 0x42 // It ne; rsb ne r5 r3 0
};
const byte kInstruction_rsb_ne_r5_r4_0[] = {
  0x18, 0xbf, 0x65, 0x42 // It ne; rsb ne r5 r4 0
};
const byte kInstruction_rsb_ne_r5_r5_0[] = {
  0x18, 0xbf, 0x6d, 0x42 // It ne; rsb ne r5 r5 0
};
const byte kInstruction_rsb_ne_r5_r6_0[] = {
  0x18, 0xbf, 0x75, 0x42 // It ne; rsb ne r5 r6 0
};
const byte kInstruction_rsb_ne_r5_r7_0[] = {
  0x18, 0xbf, 0x7d, 0x42 // It ne; rsb ne r5 r7 0
};
const byte kInstruction_rsb_ne_r6_r0_0[] = {
  0x18, 0xbf, 0x46, 0x42 // It ne; rsb ne r6 r0 0
};
const byte kInstruction_rsb_ne_r6_r1_0[] = {
  0x18, 0xbf, 0x4e, 0x42 // It ne; rsb ne r6 r1 0
};
const byte kInstruction_rsb_ne_r6_r2_0[] = {
  0x18, 0xbf, 0x56, 0x42 // It ne; rsb ne r6 r2 0
};
const byte kInstruction_rsb_ne_r6_r3_0[] = {
  0x18, 0xbf, 0x5e, 0x42 // It ne; rsb ne r6 r3 0
};
const byte kInstruction_rsb_ne_r6_r4_0[] = {
  0x18, 0xbf, 0x66, 0x42 // It ne; rsb ne r6 r4 0
};
const byte kInstruction_rsb_ne_r6_r5_0[] = {
  0x18, 0xbf, 0x6e, 0x42 // It ne; rsb ne r6 r5 0
};
const byte kInstruction_rsb_ne_r6_r6_0[] = {
  0x18, 0xbf, 0x76, 0x42 // It ne; rsb ne r6 r6 0
};
const byte kInstruction_rsb_ne_r6_r7_0[] = {
  0x18, 0xbf, 0x7e, 0x42 // It ne; rsb ne r6 r7 0
};
const byte kInstruction_rsb_ne_r7_r0_0[] = {
  0x18, 0xbf, 0x47, 0x42 // It ne; rsb ne r7 r0 0
};
const byte kInstruction_rsb_ne_r7_r1_0[] = {
  0x18, 0xbf, 0x4f, 0x42 // It ne; rsb ne r7 r1 0
};
const byte kInstruction_rsb_ne_r7_r2_0[] = {
  0x18, 0xbf, 0x57, 0x42 // It ne; rsb ne r7 r2 0
};
const byte kInstruction_rsb_ne_r7_r3_0[] = {
  0x18, 0xbf, 0x5f, 0x42 // It ne; rsb ne r7 r3 0
};
const byte kInstruction_rsb_ne_r7_r4_0[] = {
  0x18, 0xbf, 0x67, 0x42 // It ne; rsb ne r7 r4 0
};
const byte kInstruction_rsb_ne_r7_r5_0[] = {
  0x18, 0xbf, 0x6f, 0x42 // It ne; rsb ne r7 r5 0
};
const byte kInstruction_rsb_ne_r7_r6_0[] = {
  0x18, 0xbf, 0x77, 0x42 // It ne; rsb ne r7 r6 0
};
const byte kInstruction_rsb_ne_r7_r7_0[] = {
  0x18, 0xbf, 0x7f, 0x42 // It ne; rsb ne r7 r7 0
};
const byte kInstruction_rsb_cs_r0_r0_0[] = {
  0x28, 0xbf, 0x40, 0x42 // It cs; rsb cs r0 r0 0
};
const byte kInstruction_rsb_cs_r0_r1_0[] = {
  0x28, 0xbf, 0x48, 0x42 // It cs; rsb cs r0 r1 0
};
const byte kInstruction_rsb_cs_r0_r2_0[] = {
  0x28, 0xbf, 0x50, 0x42 // It cs; rsb cs r0 r2 0
};
const byte kInstruction_rsb_cs_r0_r3_0[] = {
  0x28, 0xbf, 0x58, 0x42 // It cs; rsb cs r0 r3 0
};
const byte kInstruction_rsb_cs_r0_r4_0[] = {
  0x28, 0xbf, 0x60, 0x42 // It cs; rsb cs r0 r4 0
};
const byte kInstruction_rsb_cs_r0_r5_0[] = {
  0x28, 0xbf, 0x68, 0x42 // It cs; rsb cs r0 r5 0
};
const byte kInstruction_rsb_cs_r0_r6_0[] = {
  0x28, 0xbf, 0x70, 0x42 // It cs; rsb cs r0 r6 0
};
const byte kInstruction_rsb_cs_r0_r7_0[] = {
  0x28, 0xbf, 0x78, 0x42 // It cs; rsb cs r0 r7 0
};
const byte kInstruction_rsb_cs_r1_r0_0[] = {
  0x28, 0xbf, 0x41, 0x42 // It cs; rsb cs r1 r0 0
};
const byte kInstruction_rsb_cs_r1_r1_0[] = {
  0x28, 0xbf, 0x49, 0x42 // It cs; rsb cs r1 r1 0
};
const byte kInstruction_rsb_cs_r1_r2_0[] = {
  0x28, 0xbf, 0x51, 0x42 // It cs; rsb cs r1 r2 0
};
const byte kInstruction_rsb_cs_r1_r3_0[] = {
  0x28, 0xbf, 0x59, 0x42 // It cs; rsb cs r1 r3 0
};
const byte kInstruction_rsb_cs_r1_r4_0[] = {
  0x28, 0xbf, 0x61, 0x42 // It cs; rsb cs r1 r4 0
};
const byte kInstruction_rsb_cs_r1_r5_0[] = {
  0x28, 0xbf, 0x69, 0x42 // It cs; rsb cs r1 r5 0
};
const byte kInstruction_rsb_cs_r1_r6_0[] = {
  0x28, 0xbf, 0x71, 0x42 // It cs; rsb cs r1 r6 0
};
const byte kInstruction_rsb_cs_r1_r7_0[] = {
  0x28, 0xbf, 0x79, 0x42 // It cs; rsb cs r1 r7 0
};
const byte kInstruction_rsb_cs_r2_r0_0[] = {
  0x28, 0xbf, 0x42, 0x42 // It cs; rsb cs r2 r0 0
};
const byte kInstruction_rsb_cs_r2_r1_0[] = {
  0x28, 0xbf, 0x4a, 0x42 // It cs; rsb cs r2 r1 0
};
const byte kInstruction_rsb_cs_r2_r2_0[] = {
  0x28, 0xbf, 0x52, 0x42 // It cs; rsb cs r2 r2 0
};
const byte kInstruction_rsb_cs_r2_r3_0[] = {
  0x28, 0xbf, 0x5a, 0x42 // It cs; rsb cs r2 r3 0
};
const byte kInstruction_rsb_cs_r2_r4_0[] = {
  0x28, 0xbf, 0x62, 0x42 // It cs; rsb cs r2 r4 0
};
const byte kInstruction_rsb_cs_r2_r5_0[] = {
  0x28, 0xbf, 0x6a, 0x42 // It cs; rsb cs r2 r5 0
};
const byte kInstruction_rsb_cs_r2_r6_0[] = {
  0x28, 0xbf, 0x72, 0x42 // It cs; rsb cs r2 r6 0
};
const byte kInstruction_rsb_cs_r2_r7_0[] = {
  0x28, 0xbf, 0x7a, 0x42 // It cs; rsb cs r2 r7 0
};
const byte kInstruction_rsb_cs_r3_r0_0[] = {
  0x28, 0xbf, 0x43, 0x42 // It cs; rsb cs r3 r0 0
};
const byte kInstruction_rsb_cs_r3_r1_0[] = {
  0x28, 0xbf, 0x4b, 0x42 // It cs; rsb cs r3 r1 0
};
const byte kInstruction_rsb_cs_r3_r2_0[] = {
  0x28, 0xbf, 0x53, 0x42 // It cs; rsb cs r3 r2 0
};
const byte kInstruction_rsb_cs_r3_r3_0[] = {
  0x28, 0xbf, 0x5b, 0x42 // It cs; rsb cs r3 r3 0
};
const byte kInstruction_rsb_cs_r3_r4_0[] = {
  0x28, 0xbf, 0x63, 0x42 // It cs; rsb cs r3 r4 0
};
const byte kInstruction_rsb_cs_r3_r5_0[] = {
  0x28, 0xbf, 0x6b, 0x42 // It cs; rsb cs r3 r5 0
};
const byte kInstruction_rsb_cs_r3_r6_0[] = {
  0x28, 0xbf, 0x73, 0x42 // It cs; rsb cs r3 r6 0
};
const byte kInstruction_rsb_cs_r3_r7_0[] = {
  0x28, 0xbf, 0x7b, 0x42 // It cs; rsb cs r3 r7 0
};
const byte kInstruction_rsb_cs_r4_r0_0[] = {
  0x28, 0xbf, 0x44, 0x42 // It cs; rsb cs r4 r0 0
};
const byte kInstruction_rsb_cs_r4_r1_0[] = {
  0x28, 0xbf, 0x4c, 0x42 // It cs; rsb cs r4 r1 0
};
const byte kInstruction_rsb_cs_r4_r2_0[] = {
  0x28, 0xbf, 0x54, 0x42 // It cs; rsb cs r4 r2 0
};
const byte kInstruction_rsb_cs_r4_r3_0[] = {
  0x28, 0xbf, 0x5c, 0x42 // It cs; rsb cs r4 r3 0
};
const byte kInstruction_rsb_cs_r4_r4_0[] = {
  0x28, 0xbf, 0x64, 0x42 // It cs; rsb cs r4 r4 0
};
const byte kInstruction_rsb_cs_r4_r5_0[] = {
  0x28, 0xbf, 0x6c, 0x42 // It cs; rsb cs r4 r5 0
};
const byte kInstruction_rsb_cs_r4_r6_0[] = {
  0x28, 0xbf, 0x74, 0x42 // It cs; rsb cs r4 r6 0
};
const byte kInstruction_rsb_cs_r4_r7_0[] = {
  0x28, 0xbf, 0x7c, 0x42 // It cs; rsb cs r4 r7 0
};
const byte kInstruction_rsb_cs_r5_r0_0[] = {
  0x28, 0xbf, 0x45, 0x42 // It cs; rsb cs r5 r0 0
};
const byte kInstruction_rsb_cs_r5_r1_0[] = {
  0x28, 0xbf, 0x4d, 0x42 // It cs; rsb cs r5 r1 0
};
const byte kInstruction_rsb_cs_r5_r2_0[] = {
  0x28, 0xbf, 0x55, 0x42 // It cs; rsb cs r5 r2 0
};
const byte kInstruction_rsb_cs_r5_r3_0[] = {
  0x28, 0xbf, 0x5d, 0x42 // It cs; rsb cs r5 r3 0
};
const byte kInstruction_rsb_cs_r5_r4_0[] = {
  0x28, 0xbf, 0x65, 0x42 // It cs; rsb cs r5 r4 0
};
const byte kInstruction_rsb_cs_r5_r5_0[] = {
  0x28, 0xbf, 0x6d, 0x42 // It cs; rsb cs r5 r5 0
};
const byte kInstruction_rsb_cs_r5_r6_0[] = {
  0x28, 0xbf, 0x75, 0x42 // It cs; rsb cs r5 r6 0
};
const byte kInstruction_rsb_cs_r5_r7_0[] = {
  0x28, 0xbf, 0x7d, 0x42 // It cs; rsb cs r5 r7 0
};
const byte kInstruction_rsb_cs_r6_r0_0[] = {
  0x28, 0xbf, 0x46, 0x42 // It cs; rsb cs r6 r0 0
};
const byte kInstruction_rsb_cs_r6_r1_0[] = {
  0x28, 0xbf, 0x4e, 0x42 // It cs; rsb cs r6 r1 0
};
const byte kInstruction_rsb_cs_r6_r2_0[] = {
  0x28, 0xbf, 0x56, 0x42 // It cs; rsb cs r6 r2 0
};
const byte kInstruction_rsb_cs_r6_r3_0[] = {
  0x28, 0xbf, 0x5e, 0x42 // It cs; rsb cs r6 r3 0
};
const byte kInstruction_rsb_cs_r6_r4_0[] = {
  0x28, 0xbf, 0x66, 0x42 // It cs; rsb cs r6 r4 0
};
const byte kInstruction_rsb_cs_r6_r5_0[] = {
  0x28, 0xbf, 0x6e, 0x42 // It cs; rsb cs r6 r5 0
};
const byte kInstruction_rsb_cs_r6_r6_0[] = {
  0x28, 0xbf, 0x76, 0x42 // It cs; rsb cs r6 r6 0
};
const byte kInstruction_rsb_cs_r6_r7_0[] = {
  0x28, 0xbf, 0x7e, 0x42 // It cs; rsb cs r6 r7 0
};
const byte kInstruction_rsb_cs_r7_r0_0[] = {
  0x28, 0xbf, 0x47, 0x42 // It cs; rsb cs r7 r0 0
};
const byte kInstruction_rsb_cs_r7_r1_0[] = {
  0x28, 0xbf, 0x4f, 0x42 // It cs; rsb cs r7 r1 0
};
const byte kInstruction_rsb_cs_r7_r2_0[] = {
  0x28, 0xbf, 0x57, 0x42 // It cs; rsb cs r7 r2 0
};
const byte kInstruction_rsb_cs_r7_r3_0[] = {
  0x28, 0xbf, 0x5f, 0x42 // It cs; rsb cs r7 r3 0
};
const byte kInstruction_rsb_cs_r7_r4_0[] = {
  0x28, 0xbf, 0x67, 0x42 // It cs; rsb cs r7 r4 0
};
const byte kInstruction_rsb_cs_r7_r5_0[] = {
  0x28, 0xbf, 0x6f, 0x42 // It cs; rsb cs r7 r5 0
};
const byte kInstruction_rsb_cs_r7_r6_0[] = {
  0x28, 0xbf, 0x77, 0x42 // It cs; rsb cs r7 r6 0
};
const byte kInstruction_rsb_cs_r7_r7_0[] = {
  0x28, 0xbf, 0x7f, 0x42 // It cs; rsb cs r7 r7 0
};
const byte kInstruction_rsb_cc_r0_r0_0[] = {
  0x38, 0xbf, 0x40, 0x42 // It cc; rsb cc r0 r0 0
};
const byte kInstruction_rsb_cc_r0_r1_0[] = {
  0x38, 0xbf, 0x48, 0x42 // It cc; rsb cc r0 r1 0
};
const byte kInstruction_rsb_cc_r0_r2_0[] = {
  0x38, 0xbf, 0x50, 0x42 // It cc; rsb cc r0 r2 0
};
const byte kInstruction_rsb_cc_r0_r3_0[] = {
  0x38, 0xbf, 0x58, 0x42 // It cc; rsb cc r0 r3 0
};
const byte kInstruction_rsb_cc_r0_r4_0[] = {
  0x38, 0xbf, 0x60, 0x42 // It cc; rsb cc r0 r4 0
};
const byte kInstruction_rsb_cc_r0_r5_0[] = {
  0x38, 0xbf, 0x68, 0x42 // It cc; rsb cc r0 r5 0
};
const byte kInstruction_rsb_cc_r0_r6_0[] = {
  0x38, 0xbf, 0x70, 0x42 // It cc; rsb cc r0 r6 0
};
const byte kInstruction_rsb_cc_r0_r7_0[] = {
  0x38, 0xbf, 0x78, 0x42 // It cc; rsb cc r0 r7 0
};
const byte kInstruction_rsb_cc_r1_r0_0[] = {
  0x38, 0xbf, 0x41, 0x42 // It cc; rsb cc r1 r0 0
};
const byte kInstruction_rsb_cc_r1_r1_0[] = {
  0x38, 0xbf, 0x49, 0x42 // It cc; rsb cc r1 r1 0
};
const byte kInstruction_rsb_cc_r1_r2_0[] = {
  0x38, 0xbf, 0x51, 0x42 // It cc; rsb cc r1 r2 0
};
const byte kInstruction_rsb_cc_r1_r3_0[] = {
  0x38, 0xbf, 0x59, 0x42 // It cc; rsb cc r1 r3 0
};
const byte kInstruction_rsb_cc_r1_r4_0[] = {
  0x38, 0xbf, 0x61, 0x42 // It cc; rsb cc r1 r4 0
};
const byte kInstruction_rsb_cc_r1_r5_0[] = {
  0x38, 0xbf, 0x69, 0x42 // It cc; rsb cc r1 r5 0
};
const byte kInstruction_rsb_cc_r1_r6_0[] = {
  0x38, 0xbf, 0x71, 0x42 // It cc; rsb cc r1 r6 0
};
const byte kInstruction_rsb_cc_r1_r7_0[] = {
  0x38, 0xbf, 0x79, 0x42 // It cc; rsb cc r1 r7 0
};
const byte kInstruction_rsb_cc_r2_r0_0[] = {
  0x38, 0xbf, 0x42, 0x42 // It cc; rsb cc r2 r0 0
};
const byte kInstruction_rsb_cc_r2_r1_0[] = {
  0x38, 0xbf, 0x4a, 0x42 // It cc; rsb cc r2 r1 0
};
const byte kInstruction_rsb_cc_r2_r2_0[] = {
  0x38, 0xbf, 0x52, 0x42 // It cc; rsb cc r2 r2 0
};
const byte kInstruction_rsb_cc_r2_r3_0[] = {
  0x38, 0xbf, 0x5a, 0x42 // It cc; rsb cc r2 r3 0
};
const byte kInstruction_rsb_cc_r2_r4_0[] = {
  0x38, 0xbf, 0x62, 0x42 // It cc; rsb cc r2 r4 0
};
const byte kInstruction_rsb_cc_r2_r5_0[] = {
  0x38, 0xbf, 0x6a, 0x42 // It cc; rsb cc r2 r5 0
};
const byte kInstruction_rsb_cc_r2_r6_0[] = {
  0x38, 0xbf, 0x72, 0x42 // It cc; rsb cc r2 r6 0
};
const byte kInstruction_rsb_cc_r2_r7_0[] = {
  0x38, 0xbf, 0x7a, 0x42 // It cc; rsb cc r2 r7 0
};
const byte kInstruction_rsb_cc_r3_r0_0[] = {
  0x38, 0xbf, 0x43, 0x42 // It cc; rsb cc r3 r0 0
};
const byte kInstruction_rsb_cc_r3_r1_0[] = {
  0x38, 0xbf, 0x4b, 0x42 // It cc; rsb cc r3 r1 0
};
const byte kInstruction_rsb_cc_r3_r2_0[] = {
  0x38, 0xbf, 0x53, 0x42 // It cc; rsb cc r3 r2 0
};
const byte kInstruction_rsb_cc_r3_r3_0[] = {
  0x38, 0xbf, 0x5b, 0x42 // It cc; rsb cc r3 r3 0
};
const byte kInstruction_rsb_cc_r3_r4_0[] = {
  0x38, 0xbf, 0x63, 0x42 // It cc; rsb cc r3 r4 0
};
const byte kInstruction_rsb_cc_r3_r5_0[] = {
  0x38, 0xbf, 0x6b, 0x42 // It cc; rsb cc r3 r5 0
};
const byte kInstruction_rsb_cc_r3_r6_0[] = {
  0x38, 0xbf, 0x73, 0x42 // It cc; rsb cc r3 r6 0
};
const byte kInstruction_rsb_cc_r3_r7_0[] = {
  0x38, 0xbf, 0x7b, 0x42 // It cc; rsb cc r3 r7 0
};
const byte kInstruction_rsb_cc_r4_r0_0[] = {
  0x38, 0xbf, 0x44, 0x42 // It cc; rsb cc r4 r0 0
};
const byte kInstruction_rsb_cc_r4_r1_0[] = {
  0x38, 0xbf, 0x4c, 0x42 // It cc; rsb cc r4 r1 0
};
const byte kInstruction_rsb_cc_r4_r2_0[] = {
  0x38, 0xbf, 0x54, 0x42 // It cc; rsb cc r4 r2 0
};
const byte kInstruction_rsb_cc_r4_r3_0[] = {
  0x38, 0xbf, 0x5c, 0x42 // It cc; rsb cc r4 r3 0
};
const byte kInstruction_rsb_cc_r4_r4_0[] = {
  0x38, 0xbf, 0x64, 0x42 // It cc; rsb cc r4 r4 0
};
const byte kInstruction_rsb_cc_r4_r5_0[] = {
  0x38, 0xbf, 0x6c, 0x42 // It cc; rsb cc r4 r5 0
};
const byte kInstruction_rsb_cc_r4_r6_0[] = {
  0x38, 0xbf, 0x74, 0x42 // It cc; rsb cc r4 r6 0
};
const byte kInstruction_rsb_cc_r4_r7_0[] = {
  0x38, 0xbf, 0x7c, 0x42 // It cc; rsb cc r4 r7 0
};
const byte kInstruction_rsb_cc_r5_r0_0[] = {
  0x38, 0xbf, 0x45, 0x42 // It cc; rsb cc r5 r0 0
};
const byte kInstruction_rsb_cc_r5_r1_0[] = {
  0x38, 0xbf, 0x4d, 0x42 // It cc; rsb cc r5 r1 0
};
const byte kInstruction_rsb_cc_r5_r2_0[] = {
  0x38, 0xbf, 0x55, 0x42 // It cc; rsb cc r5 r2 0
};
const byte kInstruction_rsb_cc_r5_r3_0[] = {
  0x38, 0xbf, 0x5d, 0x42 // It cc; rsb cc r5 r3 0
};
const byte kInstruction_rsb_cc_r5_r4_0[] = {
  0x38, 0xbf, 0x65, 0x42 // It cc; rsb cc r5 r4 0
};
const byte kInstruction_rsb_cc_r5_r5_0[] = {
  0x38, 0xbf, 0x6d, 0x42 // It cc; rsb cc r5 r5 0
};
const byte kInstruction_rsb_cc_r5_r6_0[] = {
  0x38, 0xbf, 0x75, 0x42 // It cc; rsb cc r5 r6 0
};
const byte kInstruction_rsb_cc_r5_r7_0[] = {
  0x38, 0xbf, 0x7d, 0x42 // It cc; rsb cc r5 r7 0
};
const byte kInstruction_rsb_cc_r6_r0_0[] = {
  0x38, 0xbf, 0x46, 0x42 // It cc; rsb cc r6 r0 0
};
const byte kInstruction_rsb_cc_r6_r1_0[] = {
  0x38, 0xbf, 0x4e, 0x42 // It cc; rsb cc r6 r1 0
};
const byte kInstruction_rsb_cc_r6_r2_0[] = {
  0x38, 0xbf, 0x56, 0x42 // It cc; rsb cc r6 r2 0
};
const byte kInstruction_rsb_cc_r6_r3_0[] = {
  0x38, 0xbf, 0x5e, 0x42 // It cc; rsb cc r6 r3 0
};
const byte kInstruction_rsb_cc_r6_r4_0[] = {
  0x38, 0xbf, 0x66, 0x42 // It cc; rsb cc r6 r4 0
};
const byte kInstruction_rsb_cc_r6_r5_0[] = {
  0x38, 0xbf, 0x6e, 0x42 // It cc; rsb cc r6 r5 0
};
const byte kInstruction_rsb_cc_r6_r6_0[] = {
  0x38, 0xbf, 0x76, 0x42 // It cc; rsb cc r6 r6 0
};
const byte kInstruction_rsb_cc_r6_r7_0[] = {
  0x38, 0xbf, 0x7e, 0x42 // It cc; rsb cc r6 r7 0
};
const byte kInstruction_rsb_cc_r7_r0_0[] = {
  0x38, 0xbf, 0x47, 0x42 // It cc; rsb cc r7 r0 0
};
const byte kInstruction_rsb_cc_r7_r1_0[] = {
  0x38, 0xbf, 0x4f, 0x42 // It cc; rsb cc r7 r1 0
};
const byte kInstruction_rsb_cc_r7_r2_0[] = {
  0x38, 0xbf, 0x57, 0x42 // It cc; rsb cc r7 r2 0
};
const byte kInstruction_rsb_cc_r7_r3_0[] = {
  0x38, 0xbf, 0x5f, 0x42 // It cc; rsb cc r7 r3 0
};
const byte kInstruction_rsb_cc_r7_r4_0[] = {
  0x38, 0xbf, 0x67, 0x42 // It cc; rsb cc r7 r4 0
};
const byte kInstruction_rsb_cc_r7_r5_0[] = {
  0x38, 0xbf, 0x6f, 0x42 // It cc; rsb cc r7 r5 0
};
const byte kInstruction_rsb_cc_r7_r6_0[] = {
  0x38, 0xbf, 0x77, 0x42 // It cc; rsb cc r7 r6 0
};
const byte kInstruction_rsb_cc_r7_r7_0[] = {
  0x38, 0xbf, 0x7f, 0x42 // It cc; rsb cc r7 r7 0
};
const byte kInstruction_rsb_mi_r0_r0_0[] = {
  0x48, 0xbf, 0x40, 0x42 // It mi; rsb mi r0 r0 0
};
const byte kInstruction_rsb_mi_r0_r1_0[] = {
  0x48, 0xbf, 0x48, 0x42 // It mi; rsb mi r0 r1 0
};
const byte kInstruction_rsb_mi_r0_r2_0[] = {
  0x48, 0xbf, 0x50, 0x42 // It mi; rsb mi r0 r2 0
};
const byte kInstruction_rsb_mi_r0_r3_0[] = {
  0x48, 0xbf, 0x58, 0x42 // It mi; rsb mi r0 r3 0
};
const byte kInstruction_rsb_mi_r0_r4_0[] = {
  0x48, 0xbf, 0x60, 0x42 // It mi; rsb mi r0 r4 0
};
const byte kInstruction_rsb_mi_r0_r5_0[] = {
  0x48, 0xbf, 0x68, 0x42 // It mi; rsb mi r0 r5 0
};
const byte kInstruction_rsb_mi_r0_r6_0[] = {
  0x48, 0xbf, 0x70, 0x42 // It mi; rsb mi r0 r6 0
};
const byte kInstruction_rsb_mi_r0_r7_0[] = {
  0x48, 0xbf, 0x78, 0x42 // It mi; rsb mi r0 r7 0
};
const byte kInstruction_rsb_mi_r1_r0_0[] = {
  0x48, 0xbf, 0x41, 0x42 // It mi; rsb mi r1 r0 0
};
const byte kInstruction_rsb_mi_r1_r1_0[] = {
  0x48, 0xbf, 0x49, 0x42 // It mi; rsb mi r1 r1 0
};
const byte kInstruction_rsb_mi_r1_r2_0[] = {
  0x48, 0xbf, 0x51, 0x42 // It mi; rsb mi r1 r2 0
};
const byte kInstruction_rsb_mi_r1_r3_0[] = {
  0x48, 0xbf, 0x59, 0x42 // It mi; rsb mi r1 r3 0
};
const byte kInstruction_rsb_mi_r1_r4_0[] = {
  0x48, 0xbf, 0x61, 0x42 // It mi; rsb mi r1 r4 0
};
const byte kInstruction_rsb_mi_r1_r5_0[] = {
  0x48, 0xbf, 0x69, 0x42 // It mi; rsb mi r1 r5 0
};
const byte kInstruction_rsb_mi_r1_r6_0[] = {
  0x48, 0xbf, 0x71, 0x42 // It mi; rsb mi r1 r6 0
};
const byte kInstruction_rsb_mi_r1_r7_0[] = {
  0x48, 0xbf, 0x79, 0x42 // It mi; rsb mi r1 r7 0
};
const byte kInstruction_rsb_mi_r2_r0_0[] = {
  0x48, 0xbf, 0x42, 0x42 // It mi; rsb mi r2 r0 0
};
const byte kInstruction_rsb_mi_r2_r1_0[] = {
  0x48, 0xbf, 0x4a, 0x42 // It mi; rsb mi r2 r1 0
};
const byte kInstruction_rsb_mi_r2_r2_0[] = {
  0x48, 0xbf, 0x52, 0x42 // It mi; rsb mi r2 r2 0
};
const byte kInstruction_rsb_mi_r2_r3_0[] = {
  0x48, 0xbf, 0x5a, 0x42 // It mi; rsb mi r2 r3 0
};
const byte kInstruction_rsb_mi_r2_r4_0[] = {
  0x48, 0xbf, 0x62, 0x42 // It mi; rsb mi r2 r4 0
};
const byte kInstruction_rsb_mi_r2_r5_0[] = {
  0x48, 0xbf, 0x6a, 0x42 // It mi; rsb mi r2 r5 0
};
const byte kInstruction_rsb_mi_r2_r6_0[] = {
  0x48, 0xbf, 0x72, 0x42 // It mi; rsb mi r2 r6 0
};
const byte kInstruction_rsb_mi_r2_r7_0[] = {
  0x48, 0xbf, 0x7a, 0x42 // It mi; rsb mi r2 r7 0
};
const byte kInstruction_rsb_mi_r3_r0_0[] = {
  0x48, 0xbf, 0x43, 0x42 // It mi; rsb mi r3 r0 0
};
const byte kInstruction_rsb_mi_r3_r1_0[] = {
  0x48, 0xbf, 0x4b, 0x42 // It mi; rsb mi r3 r1 0
};
const byte kInstruction_rsb_mi_r3_r2_0[] = {
  0x48, 0xbf, 0x53, 0x42 // It mi; rsb mi r3 r2 0
};
const byte kInstruction_rsb_mi_r3_r3_0[] = {
  0x48, 0xbf, 0x5b, 0x42 // It mi; rsb mi r3 r3 0
};
const byte kInstruction_rsb_mi_r3_r4_0[] = {
  0x48, 0xbf, 0x63, 0x42 // It mi; rsb mi r3 r4 0
};
const byte kInstruction_rsb_mi_r3_r5_0[] = {
  0x48, 0xbf, 0x6b, 0x42 // It mi; rsb mi r3 r5 0
};
const byte kInstruction_rsb_mi_r3_r6_0[] = {
  0x48, 0xbf, 0x73, 0x42 // It mi; rsb mi r3 r6 0
};
const byte kInstruction_rsb_mi_r3_r7_0[] = {
  0x48, 0xbf, 0x7b, 0x42 // It mi; rsb mi r3 r7 0
};
const byte kInstruction_rsb_mi_r4_r0_0[] = {
  0x48, 0xbf, 0x44, 0x42 // It mi; rsb mi r4 r0 0
};
const byte kInstruction_rsb_mi_r4_r1_0[] = {
  0x48, 0xbf, 0x4c, 0x42 // It mi; rsb mi r4 r1 0
};
const byte kInstruction_rsb_mi_r4_r2_0[] = {
  0x48, 0xbf, 0x54, 0x42 // It mi; rsb mi r4 r2 0
};
const byte kInstruction_rsb_mi_r4_r3_0[] = {
  0x48, 0xbf, 0x5c, 0x42 // It mi; rsb mi r4 r3 0
};
const byte kInstruction_rsb_mi_r4_r4_0[] = {
  0x48, 0xbf, 0x64, 0x42 // It mi; rsb mi r4 r4 0
};
const byte kInstruction_rsb_mi_r4_r5_0[] = {
  0x48, 0xbf, 0x6c, 0x42 // It mi; rsb mi r4 r5 0
};
const byte kInstruction_rsb_mi_r4_r6_0[] = {
  0x48, 0xbf, 0x74, 0x42 // It mi; rsb mi r4 r6 0
};
const byte kInstruction_rsb_mi_r4_r7_0[] = {
  0x48, 0xbf, 0x7c, 0x42 // It mi; rsb mi r4 r7 0
};
const byte kInstruction_rsb_mi_r5_r0_0[] = {
  0x48, 0xbf, 0x45, 0x42 // It mi; rsb mi r5 r0 0
};
const byte kInstruction_rsb_mi_r5_r1_0[] = {
  0x48, 0xbf, 0x4d, 0x42 // It mi; rsb mi r5 r1 0
};
const byte kInstruction_rsb_mi_r5_r2_0[] = {
  0x48, 0xbf, 0x55, 0x42 // It mi; rsb mi r5 r2 0
};
const byte kInstruction_rsb_mi_r5_r3_0[] = {
  0x48, 0xbf, 0x5d, 0x42 // It mi; rsb mi r5 r3 0
};
const byte kInstruction_rsb_mi_r5_r4_0[] = {
  0x48, 0xbf, 0x65, 0x42 // It mi; rsb mi r5 r4 0
};
const byte kInstruction_rsb_mi_r5_r5_0[] = {
  0x48, 0xbf, 0x6d, 0x42 // It mi; rsb mi r5 r5 0
};
const byte kInstruction_rsb_mi_r5_r6_0[] = {
  0x48, 0xbf, 0x75, 0x42 // It mi; rsb mi r5 r6 0
};
const byte kInstruction_rsb_mi_r5_r7_0[] = {
  0x48, 0xbf, 0x7d, 0x42 // It mi; rsb mi r5 r7 0
};
const byte kInstruction_rsb_mi_r6_r0_0[] = {
  0x48, 0xbf, 0x46, 0x42 // It mi; rsb mi r6 r0 0
};
const byte kInstruction_rsb_mi_r6_r1_0[] = {
  0x48, 0xbf, 0x4e, 0x42 // It mi; rsb mi r6 r1 0
};
const byte kInstruction_rsb_mi_r6_r2_0[] = {
  0x48, 0xbf, 0x56, 0x42 // It mi; rsb mi r6 r2 0
};
const byte kInstruction_rsb_mi_r6_r3_0[] = {
  0x48, 0xbf, 0x5e, 0x42 // It mi; rsb mi r6 r3 0
};
const byte kInstruction_rsb_mi_r6_r4_0[] = {
  0x48, 0xbf, 0x66, 0x42 // It mi; rsb mi r6 r4 0
};
const byte kInstruction_rsb_mi_r6_r5_0[] = {
  0x48, 0xbf, 0x6e, 0x42 // It mi; rsb mi r6 r5 0
};
const byte kInstruction_rsb_mi_r6_r6_0[] = {
  0x48, 0xbf, 0x76, 0x42 // It mi; rsb mi r6 r6 0
};
const byte kInstruction_rsb_mi_r6_r7_0[] = {
  0x48, 0xbf, 0x7e, 0x42 // It mi; rsb mi r6 r7 0
};
const byte kInstruction_rsb_mi_r7_r0_0[] = {
  0x48, 0xbf, 0x47, 0x42 // It mi; rsb mi r7 r0 0
};
const byte kInstruction_rsb_mi_r7_r1_0[] = {
  0x48, 0xbf, 0x4f, 0x42 // It mi; rsb mi r7 r1 0
};
const byte kInstruction_rsb_mi_r7_r2_0[] = {
  0x48, 0xbf, 0x57, 0x42 // It mi; rsb mi r7 r2 0
};
const byte kInstruction_rsb_mi_r7_r3_0[] = {
  0x48, 0xbf, 0x5f, 0x42 // It mi; rsb mi r7 r3 0
};
const byte kInstruction_rsb_mi_r7_r4_0[] = {
  0x48, 0xbf, 0x67, 0x42 // It mi; rsb mi r7 r4 0
};
const byte kInstruction_rsb_mi_r7_r5_0[] = {
  0x48, 0xbf, 0x6f, 0x42 // It mi; rsb mi r7 r5 0
};
const byte kInstruction_rsb_mi_r7_r6_0[] = {
  0x48, 0xbf, 0x77, 0x42 // It mi; rsb mi r7 r6 0
};
const byte kInstruction_rsb_mi_r7_r7_0[] = {
  0x48, 0xbf, 0x7f, 0x42 // It mi; rsb mi r7 r7 0
};
const byte kInstruction_rsb_pl_r0_r0_0[] = {
  0x58, 0xbf, 0x40, 0x42 // It pl; rsb pl r0 r0 0
};
const byte kInstruction_rsb_pl_r0_r1_0[] = {
  0x58, 0xbf, 0x48, 0x42 // It pl; rsb pl r0 r1 0
};
const byte kInstruction_rsb_pl_r0_r2_0[] = {
  0x58, 0xbf, 0x50, 0x42 // It pl; rsb pl r0 r2 0
};
const byte kInstruction_rsb_pl_r0_r3_0[] = {
  0x58, 0xbf, 0x58, 0x42 // It pl; rsb pl r0 r3 0
};
const byte kInstruction_rsb_pl_r0_r4_0[] = {
  0x58, 0xbf, 0x60, 0x42 // It pl; rsb pl r0 r4 0
};
const byte kInstruction_rsb_pl_r0_r5_0[] = {
  0x58, 0xbf, 0x68, 0x42 // It pl; rsb pl r0 r5 0
};
const byte kInstruction_rsb_pl_r0_r6_0[] = {
  0x58, 0xbf, 0x70, 0x42 // It pl; rsb pl r0 r6 0
};
const byte kInstruction_rsb_pl_r0_r7_0[] = {
  0x58, 0xbf, 0x78, 0x42 // It pl; rsb pl r0 r7 0
};
const byte kInstruction_rsb_pl_r1_r0_0[] = {
  0x58, 0xbf, 0x41, 0x42 // It pl; rsb pl r1 r0 0
};
const byte kInstruction_rsb_pl_r1_r1_0[] = {
  0x58, 0xbf, 0x49, 0x42 // It pl; rsb pl r1 r1 0
};
const byte kInstruction_rsb_pl_r1_r2_0[] = {
  0x58, 0xbf, 0x51, 0x42 // It pl; rsb pl r1 r2 0
};
const byte kInstruction_rsb_pl_r1_r3_0[] = {
  0x58, 0xbf, 0x59, 0x42 // It pl; rsb pl r1 r3 0
};
const byte kInstruction_rsb_pl_r1_r4_0[] = {
  0x58, 0xbf, 0x61, 0x42 // It pl; rsb pl r1 r4 0
};
const byte kInstruction_rsb_pl_r1_r5_0[] = {
  0x58, 0xbf, 0x69, 0x42 // It pl; rsb pl r1 r5 0
};
const byte kInstruction_rsb_pl_r1_r6_0[] = {
  0x58, 0xbf, 0x71, 0x42 // It pl; rsb pl r1 r6 0
};
const byte kInstruction_rsb_pl_r1_r7_0[] = {
  0x58, 0xbf, 0x79, 0x42 // It pl; rsb pl r1 r7 0
};
const byte kInstruction_rsb_pl_r2_r0_0[] = {
  0x58, 0xbf, 0x42, 0x42 // It pl; rsb pl r2 r0 0
};
const byte kInstruction_rsb_pl_r2_r1_0[] = {
  0x58, 0xbf, 0x4a, 0x42 // It pl; rsb pl r2 r1 0
};
const byte kInstruction_rsb_pl_r2_r2_0[] = {
  0x58, 0xbf, 0x52, 0x42 // It pl; rsb pl r2 r2 0
};
const byte kInstruction_rsb_pl_r2_r3_0[] = {
  0x58, 0xbf, 0x5a, 0x42 // It pl; rsb pl r2 r3 0
};
const byte kInstruction_rsb_pl_r2_r4_0[] = {
  0x58, 0xbf, 0x62, 0x42 // It pl; rsb pl r2 r4 0
};
const byte kInstruction_rsb_pl_r2_r5_0[] = {
  0x58, 0xbf, 0x6a, 0x42 // It pl; rsb pl r2 r5 0
};
const byte kInstruction_rsb_pl_r2_r6_0[] = {
  0x58, 0xbf, 0x72, 0x42 // It pl; rsb pl r2 r6 0
};
const byte kInstruction_rsb_pl_r2_r7_0[] = {
  0x58, 0xbf, 0x7a, 0x42 // It pl; rsb pl r2 r7 0
};
const byte kInstruction_rsb_pl_r3_r0_0[] = {
  0x58, 0xbf, 0x43, 0x42 // It pl; rsb pl r3 r0 0
};
const byte kInstruction_rsb_pl_r3_r1_0[] = {
  0x58, 0xbf, 0x4b, 0x42 // It pl; rsb pl r3 r1 0
};
const byte kInstruction_rsb_pl_r3_r2_0[] = {
  0x58, 0xbf, 0x53, 0x42 // It pl; rsb pl r3 r2 0
};
const byte kInstruction_rsb_pl_r3_r3_0[] = {
  0x58, 0xbf, 0x5b, 0x42 // It pl; rsb pl r3 r3 0
};
const byte kInstruction_rsb_pl_r3_r4_0[] = {
  0x58, 0xbf, 0x63, 0x42 // It pl; rsb pl r3 r4 0
};
const byte kInstruction_rsb_pl_r3_r5_0[] = {
  0x58, 0xbf, 0x6b, 0x42 // It pl; rsb pl r3 r5 0
};
const byte kInstruction_rsb_pl_r3_r6_0[] = {
  0x58, 0xbf, 0x73, 0x42 // It pl; rsb pl r3 r6 0
};
const byte kInstruction_rsb_pl_r3_r7_0[] = {
  0x58, 0xbf, 0x7b, 0x42 // It pl; rsb pl r3 r7 0
};
const byte kInstruction_rsb_pl_r4_r0_0[] = {
  0x58, 0xbf, 0x44, 0x42 // It pl; rsb pl r4 r0 0
};
const byte kInstruction_rsb_pl_r4_r1_0[] = {
  0x58, 0xbf, 0x4c, 0x42 // It pl; rsb pl r4 r1 0
};
const byte kInstruction_rsb_pl_r4_r2_0[] = {
  0x58, 0xbf, 0x54, 0x42 // It pl; rsb pl r4 r2 0
};
const byte kInstruction_rsb_pl_r4_r3_0[] = {
  0x58, 0xbf, 0x5c, 0x42 // It pl; rsb pl r4 r3 0
};
const byte kInstruction_rsb_pl_r4_r4_0[] = {
  0x58, 0xbf, 0x64, 0x42 // It pl; rsb pl r4 r4 0
};
const byte kInstruction_rsb_pl_r4_r5_0[] = {
  0x58, 0xbf, 0x6c, 0x42 // It pl; rsb pl r4 r5 0
};
const byte kInstruction_rsb_pl_r4_r6_0[] = {
  0x58, 0xbf, 0x74, 0x42 // It pl; rsb pl r4 r6 0
};
const byte kInstruction_rsb_pl_r4_r7_0[] = {
  0x58, 0xbf, 0x7c, 0x42 // It pl; rsb pl r4 r7 0
};
const byte kInstruction_rsb_pl_r5_r0_0[] = {
  0x58, 0xbf, 0x45, 0x42 // It pl; rsb pl r5 r0 0
};
const byte kInstruction_rsb_pl_r5_r1_0[] = {
  0x58, 0xbf, 0x4d, 0x42 // It pl; rsb pl r5 r1 0
};
const byte kInstruction_rsb_pl_r5_r2_0[] = {
  0x58, 0xbf, 0x55, 0x42 // It pl; rsb pl r5 r2 0
};
const byte kInstruction_rsb_pl_r5_r3_0[] = {
  0x58, 0xbf, 0x5d, 0x42 // It pl; rsb pl r5 r3 0
};
const byte kInstruction_rsb_pl_r5_r4_0[] = {
  0x58, 0xbf, 0x65, 0x42 // It pl; rsb pl r5 r4 0
};
const byte kInstruction_rsb_pl_r5_r5_0[] = {
  0x58, 0xbf, 0x6d, 0x42 // It pl; rsb pl r5 r5 0
};
const byte kInstruction_rsb_pl_r5_r6_0[] = {
  0x58, 0xbf, 0x75, 0x42 // It pl; rsb pl r5 r6 0
};
const byte kInstruction_rsb_pl_r5_r7_0[] = {
  0x58, 0xbf, 0x7d, 0x42 // It pl; rsb pl r5 r7 0
};
const byte kInstruction_rsb_pl_r6_r0_0[] = {
  0x58, 0xbf, 0x46, 0x42 // It pl; rsb pl r6 r0 0
};
const byte kInstruction_rsb_pl_r6_r1_0[] = {
  0x58, 0xbf, 0x4e, 0x42 // It pl; rsb pl r6 r1 0
};
const byte kInstruction_rsb_pl_r6_r2_0[] = {
  0x58, 0xbf, 0x56, 0x42 // It pl; rsb pl r6 r2 0
};
const byte kInstruction_rsb_pl_r6_r3_0[] = {
  0x58, 0xbf, 0x5e, 0x42 // It pl; rsb pl r6 r3 0
};
const byte kInstruction_rsb_pl_r6_r4_0[] = {
  0x58, 0xbf, 0x66, 0x42 // It pl; rsb pl r6 r4 0
};
const byte kInstruction_rsb_pl_r6_r5_0[] = {
  0x58, 0xbf, 0x6e, 0x42 // It pl; rsb pl r6 r5 0
};
const byte kInstruction_rsb_pl_r6_r6_0[] = {
  0x58, 0xbf, 0x76, 0x42 // It pl; rsb pl r6 r6 0
};
const byte kInstruction_rsb_pl_r6_r7_0[] = {
  0x58, 0xbf, 0x7e, 0x42 // It pl; rsb pl r6 r7 0
};
const byte kInstruction_rsb_pl_r7_r0_0[] = {
  0x58, 0xbf, 0x47, 0x42 // It pl; rsb pl r7 r0 0
};
const byte kInstruction_rsb_pl_r7_r1_0[] = {
  0x58, 0xbf, 0x4f, 0x42 // It pl; rsb pl r7 r1 0
};
const byte kInstruction_rsb_pl_r7_r2_0[] = {
  0x58, 0xbf, 0x57, 0x42 // It pl; rsb pl r7 r2 0
};
const byte kInstruction_rsb_pl_r7_r3_0[] = {
  0x58, 0xbf, 0x5f, 0x42 // It pl; rsb pl r7 r3 0
};
const byte kInstruction_rsb_pl_r7_r4_0[] = {
  0x58, 0xbf, 0x67, 0x42 // It pl; rsb pl r7 r4 0
};
const byte kInstruction_rsb_pl_r7_r5_0[] = {
  0x58, 0xbf, 0x6f, 0x42 // It pl; rsb pl r7 r5 0
};
const byte kInstruction_rsb_pl_r7_r6_0[] = {
  0x58, 0xbf, 0x77, 0x42 // It pl; rsb pl r7 r6 0
};
const byte kInstruction_rsb_pl_r7_r7_0[] = {
  0x58, 0xbf, 0x7f, 0x42 // It pl; rsb pl r7 r7 0
};
const byte kInstruction_rsb_vs_r0_r0_0[] = {
  0x68, 0xbf, 0x40, 0x42 // It vs; rsb vs r0 r0 0
};
const byte kInstruction_rsb_vs_r0_r1_0[] = {
  0x68, 0xbf, 0x48, 0x42 // It vs; rsb vs r0 r1 0
};
const byte kInstruction_rsb_vs_r0_r2_0[] = {
  0x68, 0xbf, 0x50, 0x42 // It vs; rsb vs r0 r2 0
};
const byte kInstruction_rsb_vs_r0_r3_0[] = {
  0x68, 0xbf, 0x58, 0x42 // It vs; rsb vs r0 r3 0
};
const byte kInstruction_rsb_vs_r0_r4_0[] = {
  0x68, 0xbf, 0x60, 0x42 // It vs; rsb vs r0 r4 0
};
const byte kInstruction_rsb_vs_r0_r5_0[] = {
  0x68, 0xbf, 0x68, 0x42 // It vs; rsb vs r0 r5 0
};
const byte kInstruction_rsb_vs_r0_r6_0[] = {
  0x68, 0xbf, 0x70, 0x42 // It vs; rsb vs r0 r6 0
};
const byte kInstruction_rsb_vs_r0_r7_0[] = {
  0x68, 0xbf, 0x78, 0x42 // It vs; rsb vs r0 r7 0
};
const byte kInstruction_rsb_vs_r1_r0_0[] = {
  0x68, 0xbf, 0x41, 0x42 // It vs; rsb vs r1 r0 0
};
const byte kInstruction_rsb_vs_r1_r1_0[] = {
  0x68, 0xbf, 0x49, 0x42 // It vs; rsb vs r1 r1 0
};
const byte kInstruction_rsb_vs_r1_r2_0[] = {
  0x68, 0xbf, 0x51, 0x42 // It vs; rsb vs r1 r2 0
};
const byte kInstruction_rsb_vs_r1_r3_0[] = {
  0x68, 0xbf, 0x59, 0x42 // It vs; rsb vs r1 r3 0
};
const byte kInstruction_rsb_vs_r1_r4_0[] = {
  0x68, 0xbf, 0x61, 0x42 // It vs; rsb vs r1 r4 0
};
const byte kInstruction_rsb_vs_r1_r5_0[] = {
  0x68, 0xbf, 0x69, 0x42 // It vs; rsb vs r1 r5 0
};
const byte kInstruction_rsb_vs_r1_r6_0[] = {
  0x68, 0xbf, 0x71, 0x42 // It vs; rsb vs r1 r6 0
};
const byte kInstruction_rsb_vs_r1_r7_0[] = {
  0x68, 0xbf, 0x79, 0x42 // It vs; rsb vs r1 r7 0
};
const byte kInstruction_rsb_vs_r2_r0_0[] = {
  0x68, 0xbf, 0x42, 0x42 // It vs; rsb vs r2 r0 0
};
const byte kInstruction_rsb_vs_r2_r1_0[] = {
  0x68, 0xbf, 0x4a, 0x42 // It vs; rsb vs r2 r1 0
};
const byte kInstruction_rsb_vs_r2_r2_0[] = {
  0x68, 0xbf, 0x52, 0x42 // It vs; rsb vs r2 r2 0
};
const byte kInstruction_rsb_vs_r2_r3_0[] = {
  0x68, 0xbf, 0x5a, 0x42 // It vs; rsb vs r2 r3 0
};
const byte kInstruction_rsb_vs_r2_r4_0[] = {
  0x68, 0xbf, 0x62, 0x42 // It vs; rsb vs r2 r4 0
};
const byte kInstruction_rsb_vs_r2_r5_0[] = {
  0x68, 0xbf, 0x6a, 0x42 // It vs; rsb vs r2 r5 0
};
const byte kInstruction_rsb_vs_r2_r6_0[] = {
  0x68, 0xbf, 0x72, 0x42 // It vs; rsb vs r2 r6 0
};
const byte kInstruction_rsb_vs_r2_r7_0[] = {
  0x68, 0xbf, 0x7a, 0x42 // It vs; rsb vs r2 r7 0
};
const byte kInstruction_rsb_vs_r3_r0_0[] = {
  0x68, 0xbf, 0x43, 0x42 // It vs; rsb vs r3 r0 0
};
const byte kInstruction_rsb_vs_r3_r1_0[] = {
  0x68, 0xbf, 0x4b, 0x42 // It vs; rsb vs r3 r1 0
};
const byte kInstruction_rsb_vs_r3_r2_0[] = {
  0x68, 0xbf, 0x53, 0x42 // It vs; rsb vs r3 r2 0
};
const byte kInstruction_rsb_vs_r3_r3_0[] = {
  0x68, 0xbf, 0x5b, 0x42 // It vs; rsb vs r3 r3 0
};
const byte kInstruction_rsb_vs_r3_r4_0[] = {
  0x68, 0xbf, 0x63, 0x42 // It vs; rsb vs r3 r4 0
};
const byte kInstruction_rsb_vs_r3_r5_0[] = {
  0x68, 0xbf, 0x6b, 0x42 // It vs; rsb vs r3 r5 0
};
const byte kInstruction_rsb_vs_r3_r6_0[] = {
  0x68, 0xbf, 0x73, 0x42 // It vs; rsb vs r3 r6 0
};
const byte kInstruction_rsb_vs_r3_r7_0[] = {
  0x68, 0xbf, 0x7b, 0x42 // It vs; rsb vs r3 r7 0
};
const byte kInstruction_rsb_vs_r4_r0_0[] = {
  0x68, 0xbf, 0x44, 0x42 // It vs; rsb vs r4 r0 0
};
const byte kInstruction_rsb_vs_r4_r1_0[] = {
  0x68, 0xbf, 0x4c, 0x42 // It vs; rsb vs r4 r1 0
};
const byte kInstruction_rsb_vs_r4_r2_0[] = {
  0x68, 0xbf, 0x54, 0x42 // It vs; rsb vs r4 r2 0
};
const byte kInstruction_rsb_vs_r4_r3_0[] = {
  0x68, 0xbf, 0x5c, 0x42 // It vs; rsb vs r4 r3 0
};
const byte kInstruction_rsb_vs_r4_r4_0[] = {
  0x68, 0xbf, 0x64, 0x42 // It vs; rsb vs r4 r4 0
};
const byte kInstruction_rsb_vs_r4_r5_0[] = {
  0x68, 0xbf, 0x6c, 0x42 // It vs; rsb vs r4 r5 0
};
const byte kInstruction_rsb_vs_r4_r6_0[] = {
  0x68, 0xbf, 0x74, 0x42 // It vs; rsb vs r4 r6 0
};
const byte kInstruction_rsb_vs_r4_r7_0[] = {
  0x68, 0xbf, 0x7c, 0x42 // It vs; rsb vs r4 r7 0
};
const byte kInstruction_rsb_vs_r5_r0_0[] = {
  0x68, 0xbf, 0x45, 0x42 // It vs; rsb vs r5 r0 0
};
const byte kInstruction_rsb_vs_r5_r1_0[] = {
  0x68, 0xbf, 0x4d, 0x42 // It vs; rsb vs r5 r1 0
};
const byte kInstruction_rsb_vs_r5_r2_0[] = {
  0x68, 0xbf, 0x55, 0x42 // It vs; rsb vs r5 r2 0
};
const byte kInstruction_rsb_vs_r5_r3_0[] = {
  0x68, 0xbf, 0x5d, 0x42 // It vs; rsb vs r5 r3 0
};
const byte kInstruction_rsb_vs_r5_r4_0[] = {
  0x68, 0xbf, 0x65, 0x42 // It vs; rsb vs r5 r4 0
};
const byte kInstruction_rsb_vs_r5_r5_0[] = {
  0x68, 0xbf, 0x6d, 0x42 // It vs; rsb vs r5 r5 0
};
const byte kInstruction_rsb_vs_r5_r6_0[] = {
  0x68, 0xbf, 0x75, 0x42 // It vs; rsb vs r5 r6 0
};
const byte kInstruction_rsb_vs_r5_r7_0[] = {
  0x68, 0xbf, 0x7d, 0x42 // It vs; rsb vs r5 r7 0
};
const byte kInstruction_rsb_vs_r6_r0_0[] = {
  0x68, 0xbf, 0x46, 0x42 // It vs; rsb vs r6 r0 0
};
const byte kInstruction_rsb_vs_r6_r1_0[] = {
  0x68, 0xbf, 0x4e, 0x42 // It vs; rsb vs r6 r1 0
};
const byte kInstruction_rsb_vs_r6_r2_0[] = {
  0x68, 0xbf, 0x56, 0x42 // It vs; rsb vs r6 r2 0
};
const byte kInstruction_rsb_vs_r6_r3_0[] = {
  0x68, 0xbf, 0x5e, 0x42 // It vs; rsb vs r6 r3 0
};
const byte kInstruction_rsb_vs_r6_r4_0[] = {
  0x68, 0xbf, 0x66, 0x42 // It vs; rsb vs r6 r4 0
};
const byte kInstruction_rsb_vs_r6_r5_0[] = {
  0x68, 0xbf, 0x6e, 0x42 // It vs; rsb vs r6 r5 0
};
const byte kInstruction_rsb_vs_r6_r6_0[] = {
  0x68, 0xbf, 0x76, 0x42 // It vs; rsb vs r6 r6 0
};
const byte kInstruction_rsb_vs_r6_r7_0[] = {
  0x68, 0xbf, 0x7e, 0x42 // It vs; rsb vs r6 r7 0
};
const byte kInstruction_rsb_vs_r7_r0_0[] = {
  0x68, 0xbf, 0x47, 0x42 // It vs; rsb vs r7 r0 0
};
const byte kInstruction_rsb_vs_r7_r1_0[] = {
  0x68, 0xbf, 0x4f, 0x42 // It vs; rsb vs r7 r1 0
};
const byte kInstruction_rsb_vs_r7_r2_0[] = {
  0x68, 0xbf, 0x57, 0x42 // It vs; rsb vs r7 r2 0
};
const byte kInstruction_rsb_vs_r7_r3_0[] = {
  0x68, 0xbf, 0x5f, 0x42 // It vs; rsb vs r7 r3 0
};
const byte kInstruction_rsb_vs_r7_r4_0[] = {
  0x68, 0xbf, 0x67, 0x42 // It vs; rsb vs r7 r4 0
};
const byte kInstruction_rsb_vs_r7_r5_0[] = {
  0x68, 0xbf, 0x6f, 0x42 // It vs; rsb vs r7 r5 0
};
const byte kInstruction_rsb_vs_r7_r6_0[] = {
  0x68, 0xbf, 0x77, 0x42 // It vs; rsb vs r7 r6 0
};
const byte kInstruction_rsb_vs_r7_r7_0[] = {
  0x68, 0xbf, 0x7f, 0x42 // It vs; rsb vs r7 r7 0
};
const byte kInstruction_rsb_vc_r0_r0_0[] = {
  0x78, 0xbf, 0x40, 0x42 // It vc; rsb vc r0 r0 0
};
const byte kInstruction_rsb_vc_r0_r1_0[] = {
  0x78, 0xbf, 0x48, 0x42 // It vc; rsb vc r0 r1 0
};
const byte kInstruction_rsb_vc_r0_r2_0[] = {
  0x78, 0xbf, 0x50, 0x42 // It vc; rsb vc r0 r2 0
};
const byte kInstruction_rsb_vc_r0_r3_0[] = {
  0x78, 0xbf, 0x58, 0x42 // It vc; rsb vc r0 r3 0
};
const byte kInstruction_rsb_vc_r0_r4_0[] = {
  0x78, 0xbf, 0x60, 0x42 // It vc; rsb vc r0 r4 0
};
const byte kInstruction_rsb_vc_r0_r5_0[] = {
  0x78, 0xbf, 0x68, 0x42 // It vc; rsb vc r0 r5 0
};
const byte kInstruction_rsb_vc_r0_r6_0[] = {
  0x78, 0xbf, 0x70, 0x42 // It vc; rsb vc r0 r6 0
};
const byte kInstruction_rsb_vc_r0_r7_0[] = {
  0x78, 0xbf, 0x78, 0x42 // It vc; rsb vc r0 r7 0
};
const byte kInstruction_rsb_vc_r1_r0_0[] = {
  0x78, 0xbf, 0x41, 0x42 // It vc; rsb vc r1 r0 0
};
const byte kInstruction_rsb_vc_r1_r1_0[] = {
  0x78, 0xbf, 0x49, 0x42 // It vc; rsb vc r1 r1 0
};
const byte kInstruction_rsb_vc_r1_r2_0[] = {
  0x78, 0xbf, 0x51, 0x42 // It vc; rsb vc r1 r2 0
};
const byte kInstruction_rsb_vc_r1_r3_0[] = {
  0x78, 0xbf, 0x59, 0x42 // It vc; rsb vc r1 r3 0
};
const byte kInstruction_rsb_vc_r1_r4_0[] = {
  0x78, 0xbf, 0x61, 0x42 // It vc; rsb vc r1 r4 0
};
const byte kInstruction_rsb_vc_r1_r5_0[] = {
  0x78, 0xbf, 0x69, 0x42 // It vc; rsb vc r1 r5 0
};
const byte kInstruction_rsb_vc_r1_r6_0[] = {
  0x78, 0xbf, 0x71, 0x42 // It vc; rsb vc r1 r6 0
};
const byte kInstruction_rsb_vc_r1_r7_0[] = {
  0x78, 0xbf, 0x79, 0x42 // It vc; rsb vc r1 r7 0
};
const byte kInstruction_rsb_vc_r2_r0_0[] = {
  0x78, 0xbf, 0x42, 0x42 // It vc; rsb vc r2 r0 0
};
const byte kInstruction_rsb_vc_r2_r1_0[] = {
  0x78, 0xbf, 0x4a, 0x42 // It vc; rsb vc r2 r1 0
};
const byte kInstruction_rsb_vc_r2_r2_0[] = {
  0x78, 0xbf, 0x52, 0x42 // It vc; rsb vc r2 r2 0
};
const byte kInstruction_rsb_vc_r2_r3_0[] = {
  0x78, 0xbf, 0x5a, 0x42 // It vc; rsb vc r2 r3 0
};
const byte kInstruction_rsb_vc_r2_r4_0[] = {
  0x78, 0xbf, 0x62, 0x42 // It vc; rsb vc r2 r4 0
};
const byte kInstruction_rsb_vc_r2_r5_0[] = {
  0x78, 0xbf, 0x6a, 0x42 // It vc; rsb vc r2 r5 0
};
const byte kInstruction_rsb_vc_r2_r6_0[] = {
  0x78, 0xbf, 0x72, 0x42 // It vc; rsb vc r2 r6 0
};
const byte kInstruction_rsb_vc_r2_r7_0[] = {
  0x78, 0xbf, 0x7a, 0x42 // It vc; rsb vc r2 r7 0
};
const byte kInstruction_rsb_vc_r3_r0_0[] = {
  0x78, 0xbf, 0x43, 0x42 // It vc; rsb vc r3 r0 0
};
const byte kInstruction_rsb_vc_r3_r1_0[] = {
  0x78, 0xbf, 0x4b, 0x42 // It vc; rsb vc r3 r1 0
};
const byte kInstruction_rsb_vc_r3_r2_0[] = {
  0x78, 0xbf, 0x53, 0x42 // It vc; rsb vc r3 r2 0
};
const byte kInstruction_rsb_vc_r3_r3_0[] = {
  0x78, 0xbf, 0x5b, 0x42 // It vc; rsb vc r3 r3 0
};
const byte kInstruction_rsb_vc_r3_r4_0[] = {
  0x78, 0xbf, 0x63, 0x42 // It vc; rsb vc r3 r4 0
};
const byte kInstruction_rsb_vc_r3_r5_0[] = {
  0x78, 0xbf, 0x6b, 0x42 // It vc; rsb vc r3 r5 0
};
const byte kInstruction_rsb_vc_r3_r6_0[] = {
  0x78, 0xbf, 0x73, 0x42 // It vc; rsb vc r3 r6 0
};
const byte kInstruction_rsb_vc_r3_r7_0[] = {
  0x78, 0xbf, 0x7b, 0x42 // It vc; rsb vc r3 r7 0
};
const byte kInstruction_rsb_vc_r4_r0_0[] = {
  0x78, 0xbf, 0x44, 0x42 // It vc; rsb vc r4 r0 0
};
const byte kInstruction_rsb_vc_r4_r1_0[] = {
  0x78, 0xbf, 0x4c, 0x42 // It vc; rsb vc r4 r1 0
};
const byte kInstruction_rsb_vc_r4_r2_0[] = {
  0x78, 0xbf, 0x54, 0x42 // It vc; rsb vc r4 r2 0
};
const byte kInstruction_rsb_vc_r4_r3_0[] = {
  0x78, 0xbf, 0x5c, 0x42 // It vc; rsb vc r4 r3 0
};
const byte kInstruction_rsb_vc_r4_r4_0[] = {
  0x78, 0xbf, 0x64, 0x42 // It vc; rsb vc r4 r4 0
};
const byte kInstruction_rsb_vc_r4_r5_0[] = {
  0x78, 0xbf, 0x6c, 0x42 // It vc; rsb vc r4 r5 0
};
const byte kInstruction_rsb_vc_r4_r6_0[] = {
  0x78, 0xbf, 0x74, 0x42 // It vc; rsb vc r4 r6 0
};
const byte kInstruction_rsb_vc_r4_r7_0[] = {
  0x78, 0xbf, 0x7c, 0x42 // It vc; rsb vc r4 r7 0
};
const byte kInstruction_rsb_vc_r5_r0_0[] = {
  0x78, 0xbf, 0x45, 0x42 // It vc; rsb vc r5 r0 0
};
const byte kInstruction_rsb_vc_r5_r1_0[] = {
  0x78, 0xbf, 0x4d, 0x42 // It vc; rsb vc r5 r1 0
};
const byte kInstruction_rsb_vc_r5_r2_0[] = {
  0x78, 0xbf, 0x55, 0x42 // It vc; rsb vc r5 r2 0
};
const byte kInstruction_rsb_vc_r5_r3_0[] = {
  0x78, 0xbf, 0x5d, 0x42 // It vc; rsb vc r5 r3 0
};
const byte kInstruction_rsb_vc_r5_r4_0[] = {
  0x78, 0xbf, 0x65, 0x42 // It vc; rsb vc r5 r4 0
};
const byte kInstruction_rsb_vc_r5_r5_0[] = {
  0x78, 0xbf, 0x6d, 0x42 // It vc; rsb vc r5 r5 0
};
const byte kInstruction_rsb_vc_r5_r6_0[] = {
  0x78, 0xbf, 0x75, 0x42 // It vc; rsb vc r5 r6 0
};
const byte kInstruction_rsb_vc_r5_r7_0[] = {
  0x78, 0xbf, 0x7d, 0x42 // It vc; rsb vc r5 r7 0
};
const byte kInstruction_rsb_vc_r6_r0_0[] = {
  0x78, 0xbf, 0x46, 0x42 // It vc; rsb vc r6 r0 0
};
const byte kInstruction_rsb_vc_r6_r1_0[] = {
  0x78, 0xbf, 0x4e, 0x42 // It vc; rsb vc r6 r1 0
};
const byte kInstruction_rsb_vc_r6_r2_0[] = {
  0x78, 0xbf, 0x56, 0x42 // It vc; rsb vc r6 r2 0
};
const byte kInstruction_rsb_vc_r6_r3_0[] = {
  0x78, 0xbf, 0x5e, 0x42 // It vc; rsb vc r6 r3 0
};
const byte kInstruction_rsb_vc_r6_r4_0[] = {
  0x78, 0xbf, 0x66, 0x42 // It vc; rsb vc r6 r4 0
};
const byte kInstruction_rsb_vc_r6_r5_0[] = {
  0x78, 0xbf, 0x6e, 0x42 // It vc; rsb vc r6 r5 0
};
const byte kInstruction_rsb_vc_r6_r6_0[] = {
  0x78, 0xbf, 0x76, 0x42 // It vc; rsb vc r6 r6 0
};
const byte kInstruction_rsb_vc_r6_r7_0[] = {
  0x78, 0xbf, 0x7e, 0x42 // It vc; rsb vc r6 r7 0
};
const byte kInstruction_rsb_vc_r7_r0_0[] = {
  0x78, 0xbf, 0x47, 0x42 // It vc; rsb vc r7 r0 0
};
const byte kInstruction_rsb_vc_r7_r1_0[] = {
  0x78, 0xbf, 0x4f, 0x42 // It vc; rsb vc r7 r1 0
};
const byte kInstruction_rsb_vc_r7_r2_0[] = {
  0x78, 0xbf, 0x57, 0x42 // It vc; rsb vc r7 r2 0
};
const byte kInstruction_rsb_vc_r7_r3_0[] = {
  0x78, 0xbf, 0x5f, 0x42 // It vc; rsb vc r7 r3 0
};
const byte kInstruction_rsb_vc_r7_r4_0[] = {
  0x78, 0xbf, 0x67, 0x42 // It vc; rsb vc r7 r4 0
};
const byte kInstruction_rsb_vc_r7_r5_0[] = {
  0x78, 0xbf, 0x6f, 0x42 // It vc; rsb vc r7 r5 0
};
const byte kInstruction_rsb_vc_r7_r6_0[] = {
  0x78, 0xbf, 0x77, 0x42 // It vc; rsb vc r7 r6 0
};
const byte kInstruction_rsb_vc_r7_r7_0[] = {
  0x78, 0xbf, 0x7f, 0x42 // It vc; rsb vc r7 r7 0
};
const byte kInstruction_rsb_hi_r0_r0_0[] = {
  0x88, 0xbf, 0x40, 0x42 // It hi; rsb hi r0 r0 0
};
const byte kInstruction_rsb_hi_r0_r1_0[] = {
  0x88, 0xbf, 0x48, 0x42 // It hi; rsb hi r0 r1 0
};
const byte kInstruction_rsb_hi_r0_r2_0[] = {
  0x88, 0xbf, 0x50, 0x42 // It hi; rsb hi r0 r2 0
};
const byte kInstruction_rsb_hi_r0_r3_0[] = {
  0x88, 0xbf, 0x58, 0x42 // It hi; rsb hi r0 r3 0
};
const byte kInstruction_rsb_hi_r0_r4_0[] = {
  0x88, 0xbf, 0x60, 0x42 // It hi; rsb hi r0 r4 0
};
const byte kInstruction_rsb_hi_r0_r5_0[] = {
  0x88, 0xbf, 0x68, 0x42 // It hi; rsb hi r0 r5 0
};
const byte kInstruction_rsb_hi_r0_r6_0[] = {
  0x88, 0xbf, 0x70, 0x42 // It hi; rsb hi r0 r6 0
};
const byte kInstruction_rsb_hi_r0_r7_0[] = {
  0x88, 0xbf, 0x78, 0x42 // It hi; rsb hi r0 r7 0
};
const byte kInstruction_rsb_hi_r1_r0_0[] = {
  0x88, 0xbf, 0x41, 0x42 // It hi; rsb hi r1 r0 0
};
const byte kInstruction_rsb_hi_r1_r1_0[] = {
  0x88, 0xbf, 0x49, 0x42 // It hi; rsb hi r1 r1 0
};
const byte kInstruction_rsb_hi_r1_r2_0[] = {
  0x88, 0xbf, 0x51, 0x42 // It hi; rsb hi r1 r2 0
};
const byte kInstruction_rsb_hi_r1_r3_0[] = {
  0x88, 0xbf, 0x59, 0x42 // It hi; rsb hi r1 r3 0
};
const byte kInstruction_rsb_hi_r1_r4_0[] = {
  0x88, 0xbf, 0x61, 0x42 // It hi; rsb hi r1 r4 0
};
const byte kInstruction_rsb_hi_r1_r5_0[] = {
  0x88, 0xbf, 0x69, 0x42 // It hi; rsb hi r1 r5 0
};
const byte kInstruction_rsb_hi_r1_r6_0[] = {
  0x88, 0xbf, 0x71, 0x42 // It hi; rsb hi r1 r6 0
};
const byte kInstruction_rsb_hi_r1_r7_0[] = {
  0x88, 0xbf, 0x79, 0x42 // It hi; rsb hi r1 r7 0
};
const byte kInstruction_rsb_hi_r2_r0_0[] = {
  0x88, 0xbf, 0x42, 0x42 // It hi; rsb hi r2 r0 0
};
const byte kInstruction_rsb_hi_r2_r1_0[] = {
  0x88, 0xbf, 0x4a, 0x42 // It hi; rsb hi r2 r1 0
};
const byte kInstruction_rsb_hi_r2_r2_0[] = {
  0x88, 0xbf, 0x52, 0x42 // It hi; rsb hi r2 r2 0
};
const byte kInstruction_rsb_hi_r2_r3_0[] = {
  0x88, 0xbf, 0x5a, 0x42 // It hi; rsb hi r2 r3 0
};
const byte kInstruction_rsb_hi_r2_r4_0[] = {
  0x88, 0xbf, 0x62, 0x42 // It hi; rsb hi r2 r4 0
};
const byte kInstruction_rsb_hi_r2_r5_0[] = {
  0x88, 0xbf, 0x6a, 0x42 // It hi; rsb hi r2 r5 0
};
const byte kInstruction_rsb_hi_r2_r6_0[] = {
  0x88, 0xbf, 0x72, 0x42 // It hi; rsb hi r2 r6 0
};
const byte kInstruction_rsb_hi_r2_r7_0[] = {
  0x88, 0xbf, 0x7a, 0x42 // It hi; rsb hi r2 r7 0
};
const byte kInstruction_rsb_hi_r3_r0_0[] = {
  0x88, 0xbf, 0x43, 0x42 // It hi; rsb hi r3 r0 0
};
const byte kInstruction_rsb_hi_r3_r1_0[] = {
  0x88, 0xbf, 0x4b, 0x42 // It hi; rsb hi r3 r1 0
};
const byte kInstruction_rsb_hi_r3_r2_0[] = {
  0x88, 0xbf, 0x53, 0x42 // It hi; rsb hi r3 r2 0
};
const byte kInstruction_rsb_hi_r3_r3_0[] = {
  0x88, 0xbf, 0x5b, 0x42 // It hi; rsb hi r3 r3 0
};
const byte kInstruction_rsb_hi_r3_r4_0[] = {
  0x88, 0xbf, 0x63, 0x42 // It hi; rsb hi r3 r4 0
};
const byte kInstruction_rsb_hi_r3_r5_0[] = {
  0x88, 0xbf, 0x6b, 0x42 // It hi; rsb hi r3 r5 0
};
const byte kInstruction_rsb_hi_r3_r6_0[] = {
  0x88, 0xbf, 0x73, 0x42 // It hi; rsb hi r3 r6 0
};
const byte kInstruction_rsb_hi_r3_r7_0[] = {
  0x88, 0xbf, 0x7b, 0x42 // It hi; rsb hi r3 r7 0
};
const byte kInstruction_rsb_hi_r4_r0_0[] = {
  0x88, 0xbf, 0x44, 0x42 // It hi; rsb hi r4 r0 0
};
const byte kInstruction_rsb_hi_r4_r1_0[] = {
  0x88, 0xbf, 0x4c, 0x42 // It hi; rsb hi r4 r1 0
};
const byte kInstruction_rsb_hi_r4_r2_0[] = {
  0x88, 0xbf, 0x54, 0x42 // It hi; rsb hi r4 r2 0
};
const byte kInstruction_rsb_hi_r4_r3_0[] = {
  0x88, 0xbf, 0x5c, 0x42 // It hi; rsb hi r4 r3 0
};
const byte kInstruction_rsb_hi_r4_r4_0[] = {
  0x88, 0xbf, 0x64, 0x42 // It hi; rsb hi r4 r4 0
};
const byte kInstruction_rsb_hi_r4_r5_0[] = {
  0x88, 0xbf, 0x6c, 0x42 // It hi; rsb hi r4 r5 0
};
const byte kInstruction_rsb_hi_r4_r6_0[] = {
  0x88, 0xbf, 0x74, 0x42 // It hi; rsb hi r4 r6 0
};
const byte kInstruction_rsb_hi_r4_r7_0[] = {
  0x88, 0xbf, 0x7c, 0x42 // It hi; rsb hi r4 r7 0
};
const byte kInstruction_rsb_hi_r5_r0_0[] = {
  0x88, 0xbf, 0x45, 0x42 // It hi; rsb hi r5 r0 0
};
const byte kInstruction_rsb_hi_r5_r1_0[] = {
  0x88, 0xbf, 0x4d, 0x42 // It hi; rsb hi r5 r1 0
};
const byte kInstruction_rsb_hi_r5_r2_0[] = {
  0x88, 0xbf, 0x55, 0x42 // It hi; rsb hi r5 r2 0
};
const byte kInstruction_rsb_hi_r5_r3_0[] = {
  0x88, 0xbf, 0x5d, 0x42 // It hi; rsb hi r5 r3 0
};
const byte kInstruction_rsb_hi_r5_r4_0[] = {
  0x88, 0xbf, 0x65, 0x42 // It hi; rsb hi r5 r4 0
};
const byte kInstruction_rsb_hi_r5_r5_0[] = {
  0x88, 0xbf, 0x6d, 0x42 // It hi; rsb hi r5 r5 0
};
const byte kInstruction_rsb_hi_r5_r6_0[] = {
  0x88, 0xbf, 0x75, 0x42 // It hi; rsb hi r5 r6 0
};
const byte kInstruction_rsb_hi_r5_r7_0[] = {
  0x88, 0xbf, 0x7d, 0x42 // It hi; rsb hi r5 r7 0
};
const byte kInstruction_rsb_hi_r6_r0_0[] = {
  0x88, 0xbf, 0x46, 0x42 // It hi; rsb hi r6 r0 0
};
const byte kInstruction_rsb_hi_r6_r1_0[] = {
  0x88, 0xbf, 0x4e, 0x42 // It hi; rsb hi r6 r1 0
};
const byte kInstruction_rsb_hi_r6_r2_0[] = {
  0x88, 0xbf, 0x56, 0x42 // It hi; rsb hi r6 r2 0
};
const byte kInstruction_rsb_hi_r6_r3_0[] = {
  0x88, 0xbf, 0x5e, 0x42 // It hi; rsb hi r6 r3 0
};
const byte kInstruction_rsb_hi_r6_r4_0[] = {
  0x88, 0xbf, 0x66, 0x42 // It hi; rsb hi r6 r4 0
};
const byte kInstruction_rsb_hi_r6_r5_0[] = {
  0x88, 0xbf, 0x6e, 0x42 // It hi; rsb hi r6 r5 0
};
const byte kInstruction_rsb_hi_r6_r6_0[] = {
  0x88, 0xbf, 0x76, 0x42 // It hi; rsb hi r6 r6 0
};
const byte kInstruction_rsb_hi_r6_r7_0[] = {
  0x88, 0xbf, 0x7e, 0x42 // It hi; rsb hi r6 r7 0
};
const byte kInstruction_rsb_hi_r7_r0_0[] = {
  0x88, 0xbf, 0x47, 0x42 // It hi; rsb hi r7 r0 0
};
const byte kInstruction_rsb_hi_r7_r1_0[] = {
  0x88, 0xbf, 0x4f, 0x42 // It hi; rsb hi r7 r1 0
};
const byte kInstruction_rsb_hi_r7_r2_0[] = {
  0x88, 0xbf, 0x57, 0x42 // It hi; rsb hi r7 r2 0
};
const byte kInstruction_rsb_hi_r7_r3_0[] = {
  0x88, 0xbf, 0x5f, 0x42 // It hi; rsb hi r7 r3 0
};
const byte kInstruction_rsb_hi_r7_r4_0[] = {
  0x88, 0xbf, 0x67, 0x42 // It hi; rsb hi r7 r4 0
};
const byte kInstruction_rsb_hi_r7_r5_0[] = {
  0x88, 0xbf, 0x6f, 0x42 // It hi; rsb hi r7 r5 0
};
const byte kInstruction_rsb_hi_r7_r6_0[] = {
  0x88, 0xbf, 0x77, 0x42 // It hi; rsb hi r7 r6 0
};
const byte kInstruction_rsb_hi_r7_r7_0[] = {
  0x88, 0xbf, 0x7f, 0x42 // It hi; rsb hi r7 r7 0
};
const byte kInstruction_rsb_ls_r0_r0_0[] = {
  0x98, 0xbf, 0x40, 0x42 // It ls; rsb ls r0 r0 0
};
const byte kInstruction_rsb_ls_r0_r1_0[] = {
  0x98, 0xbf, 0x48, 0x42 // It ls; rsb ls r0 r1 0
};
const byte kInstruction_rsb_ls_r0_r2_0[] = {
  0x98, 0xbf, 0x50, 0x42 // It ls; rsb ls r0 r2 0
};
const byte kInstruction_rsb_ls_r0_r3_0[] = {
  0x98, 0xbf, 0x58, 0x42 // It ls; rsb ls r0 r3 0
};
const byte kInstruction_rsb_ls_r0_r4_0[] = {
  0x98, 0xbf, 0x60, 0x42 // It ls; rsb ls r0 r4 0
};
const byte kInstruction_rsb_ls_r0_r5_0[] = {
  0x98, 0xbf, 0x68, 0x42 // It ls; rsb ls r0 r5 0
};
const byte kInstruction_rsb_ls_r0_r6_0[] = {
  0x98, 0xbf, 0x70, 0x42 // It ls; rsb ls r0 r6 0
};
const byte kInstruction_rsb_ls_r0_r7_0[] = {
  0x98, 0xbf, 0x78, 0x42 // It ls; rsb ls r0 r7 0
};
const byte kInstruction_rsb_ls_r1_r0_0[] = {
  0x98, 0xbf, 0x41, 0x42 // It ls; rsb ls r1 r0 0
};
const byte kInstruction_rsb_ls_r1_r1_0[] = {
  0x98, 0xbf, 0x49, 0x42 // It ls; rsb ls r1 r1 0
};
const byte kInstruction_rsb_ls_r1_r2_0[] = {
  0x98, 0xbf, 0x51, 0x42 // It ls; rsb ls r1 r2 0
};
const byte kInstruction_rsb_ls_r1_r3_0[] = {
  0x98, 0xbf, 0x59, 0x42 // It ls; rsb ls r1 r3 0
};
const byte kInstruction_rsb_ls_r1_r4_0[] = {
  0x98, 0xbf, 0x61, 0x42 // It ls; rsb ls r1 r4 0
};
const byte kInstruction_rsb_ls_r1_r5_0[] = {
  0x98, 0xbf, 0x69, 0x42 // It ls; rsb ls r1 r5 0
};
const byte kInstruction_rsb_ls_r1_r6_0[] = {
  0x98, 0xbf, 0x71, 0x42 // It ls; rsb ls r1 r6 0
};
const byte kInstruction_rsb_ls_r1_r7_0[] = {
  0x98, 0xbf, 0x79, 0x42 // It ls; rsb ls r1 r7 0
};
const byte kInstruction_rsb_ls_r2_r0_0[] = {
  0x98, 0xbf, 0x42, 0x42 // It ls; rsb ls r2 r0 0
};
const byte kInstruction_rsb_ls_r2_r1_0[] = {
  0x98, 0xbf, 0x4a, 0x42 // It ls; rsb ls r2 r1 0
};
const byte kInstruction_rsb_ls_r2_r2_0[] = {
  0x98, 0xbf, 0x52, 0x42 // It ls; rsb ls r2 r2 0
};
const byte kInstruction_rsb_ls_r2_r3_0[] = {
  0x98, 0xbf, 0x5a, 0x42 // It ls; rsb ls r2 r3 0
};
const byte kInstruction_rsb_ls_r2_r4_0[] = {
  0x98, 0xbf, 0x62, 0x42 // It ls; rsb ls r2 r4 0
};
const byte kInstruction_rsb_ls_r2_r5_0[] = {
  0x98, 0xbf, 0x6a, 0x42 // It ls; rsb ls r2 r5 0
};
const byte kInstruction_rsb_ls_r2_r6_0[] = {
  0x98, 0xbf, 0x72, 0x42 // It ls; rsb ls r2 r6 0
};
const byte kInstruction_rsb_ls_r2_r7_0[] = {
  0x98, 0xbf, 0x7a, 0x42 // It ls; rsb ls r2 r7 0
};
const byte kInstruction_rsb_ls_r3_r0_0[] = {
  0x98, 0xbf, 0x43, 0x42 // It ls; rsb ls r3 r0 0
};
const byte kInstruction_rsb_ls_r3_r1_0[] = {
  0x98, 0xbf, 0x4b, 0x42 // It ls; rsb ls r3 r1 0
};
const byte kInstruction_rsb_ls_r3_r2_0[] = {
  0x98, 0xbf, 0x53, 0x42 // It ls; rsb ls r3 r2 0
};
const byte kInstruction_rsb_ls_r3_r3_0[] = {
  0x98, 0xbf, 0x5b, 0x42 // It ls; rsb ls r3 r3 0
};
const byte kInstruction_rsb_ls_r3_r4_0[] = {
  0x98, 0xbf, 0x63, 0x42 // It ls; rsb ls r3 r4 0
};
const byte kInstruction_rsb_ls_r3_r5_0[] = {
  0x98, 0xbf, 0x6b, 0x42 // It ls; rsb ls r3 r5 0
};
const byte kInstruction_rsb_ls_r3_r6_0[] = {
  0x98, 0xbf, 0x73, 0x42 // It ls; rsb ls r3 r6 0
};
const byte kInstruction_rsb_ls_r3_r7_0[] = {
  0x98, 0xbf, 0x7b, 0x42 // It ls; rsb ls r3 r7 0
};
const byte kInstruction_rsb_ls_r4_r0_0[] = {
  0x98, 0xbf, 0x44, 0x42 // It ls; rsb ls r4 r0 0
};
const byte kInstruction_rsb_ls_r4_r1_0[] = {
  0x98, 0xbf, 0x4c, 0x42 // It ls; rsb ls r4 r1 0
};
const byte kInstruction_rsb_ls_r4_r2_0[] = {
  0x98, 0xbf, 0x54, 0x42 // It ls; rsb ls r4 r2 0
};
const byte kInstruction_rsb_ls_r4_r3_0[] = {
  0x98, 0xbf, 0x5c, 0x42 // It ls; rsb ls r4 r3 0
};
const byte kInstruction_rsb_ls_r4_r4_0[] = {
  0x98, 0xbf, 0x64, 0x42 // It ls; rsb ls r4 r4 0
};
const byte kInstruction_rsb_ls_r4_r5_0[] = {
  0x98, 0xbf, 0x6c, 0x42 // It ls; rsb ls r4 r5 0
};
const byte kInstruction_rsb_ls_r4_r6_0[] = {
  0x98, 0xbf, 0x74, 0x42 // It ls; rsb ls r4 r6 0
};
const byte kInstruction_rsb_ls_r4_r7_0[] = {
  0x98, 0xbf, 0x7c, 0x42 // It ls; rsb ls r4 r7 0
};
const byte kInstruction_rsb_ls_r5_r0_0[] = {
  0x98, 0xbf, 0x45, 0x42 // It ls; rsb ls r5 r0 0
};
const byte kInstruction_rsb_ls_r5_r1_0[] = {
  0x98, 0xbf, 0x4d, 0x42 // It ls; rsb ls r5 r1 0
};
const byte kInstruction_rsb_ls_r5_r2_0[] = {
  0x98, 0xbf, 0x55, 0x42 // It ls; rsb ls r5 r2 0
};
const byte kInstruction_rsb_ls_r5_r3_0[] = {
  0x98, 0xbf, 0x5d, 0x42 // It ls; rsb ls r5 r3 0
};
const byte kInstruction_rsb_ls_r5_r4_0[] = {
  0x98, 0xbf, 0x65, 0x42 // It ls; rsb ls r5 r4 0
};
const byte kInstruction_rsb_ls_r5_r5_0[] = {
  0x98, 0xbf, 0x6d, 0x42 // It ls; rsb ls r5 r5 0
};
const byte kInstruction_rsb_ls_r5_r6_0[] = {
  0x98, 0xbf, 0x75, 0x42 // It ls; rsb ls r5 r6 0
};
const byte kInstruction_rsb_ls_r5_r7_0[] = {
  0x98, 0xbf, 0x7d, 0x42 // It ls; rsb ls r5 r7 0
};
const byte kInstruction_rsb_ls_r6_r0_0[] = {
  0x98, 0xbf, 0x46, 0x42 // It ls; rsb ls r6 r0 0
};
const byte kInstruction_rsb_ls_r6_r1_0[] = {
  0x98, 0xbf, 0x4e, 0x42 // It ls; rsb ls r6 r1 0
};
const byte kInstruction_rsb_ls_r6_r2_0[] = {
  0x98, 0xbf, 0x56, 0x42 // It ls; rsb ls r6 r2 0
};
const byte kInstruction_rsb_ls_r6_r3_0[] = {
  0x98, 0xbf, 0x5e, 0x42 // It ls; rsb ls r6 r3 0
};
const byte kInstruction_rsb_ls_r6_r4_0[] = {
  0x98, 0xbf, 0x66, 0x42 // It ls; rsb ls r6 r4 0
};
const byte kInstruction_rsb_ls_r6_r5_0[] = {
  0x98, 0xbf, 0x6e, 0x42 // It ls; rsb ls r6 r5 0
};
const byte kInstruction_rsb_ls_r6_r6_0[] = {
  0x98, 0xbf, 0x76, 0x42 // It ls; rsb ls r6 r6 0
};
const byte kInstruction_rsb_ls_r6_r7_0[] = {
  0x98, 0xbf, 0x7e, 0x42 // It ls; rsb ls r6 r7 0
};
const byte kInstruction_rsb_ls_r7_r0_0[] = {
  0x98, 0xbf, 0x47, 0x42 // It ls; rsb ls r7 r0 0
};
const byte kInstruction_rsb_ls_r7_r1_0[] = {
  0x98, 0xbf, 0x4f, 0x42 // It ls; rsb ls r7 r1 0
};
const byte kInstruction_rsb_ls_r7_r2_0[] = {
  0x98, 0xbf, 0x57, 0x42 // It ls; rsb ls r7 r2 0
};
const byte kInstruction_rsb_ls_r7_r3_0[] = {
  0x98, 0xbf, 0x5f, 0x42 // It ls; rsb ls r7 r3 0
};
const byte kInstruction_rsb_ls_r7_r4_0[] = {
  0x98, 0xbf, 0x67, 0x42 // It ls; rsb ls r7 r4 0
};
const byte kInstruction_rsb_ls_r7_r5_0[] = {
  0x98, 0xbf, 0x6f, 0x42 // It ls; rsb ls r7 r5 0
};
const byte kInstruction_rsb_ls_r7_r6_0[] = {
  0x98, 0xbf, 0x77, 0x42 // It ls; rsb ls r7 r6 0
};
const byte kInstruction_rsb_ls_r7_r7_0[] = {
  0x98, 0xbf, 0x7f, 0x42 // It ls; rsb ls r7 r7 0
};
const byte kInstruction_rsb_ge_r0_r0_0[] = {
  0xa8, 0xbf, 0x40, 0x42 // It ge; rsb ge r0 r0 0
};
const byte kInstruction_rsb_ge_r0_r1_0[] = {
  0xa8, 0xbf, 0x48, 0x42 // It ge; rsb ge r0 r1 0
};
const byte kInstruction_rsb_ge_r0_r2_0[] = {
  0xa8, 0xbf, 0x50, 0x42 // It ge; rsb ge r0 r2 0
};
const byte kInstruction_rsb_ge_r0_r3_0[] = {
  0xa8, 0xbf, 0x58, 0x42 // It ge; rsb ge r0 r3 0
};
const byte kInstruction_rsb_ge_r0_r4_0[] = {
  0xa8, 0xbf, 0x60, 0x42 // It ge; rsb ge r0 r4 0
};
const byte kInstruction_rsb_ge_r0_r5_0[] = {
  0xa8, 0xbf, 0x68, 0x42 // It ge; rsb ge r0 r5 0
};
const byte kInstruction_rsb_ge_r0_r6_0[] = {
  0xa8, 0xbf, 0x70, 0x42 // It ge; rsb ge r0 r6 0
};
const byte kInstruction_rsb_ge_r0_r7_0[] = {
  0xa8, 0xbf, 0x78, 0x42 // It ge; rsb ge r0 r7 0
};
const byte kInstruction_rsb_ge_r1_r0_0[] = {
  0xa8, 0xbf, 0x41, 0x42 // It ge; rsb ge r1 r0 0
};
const byte kInstruction_rsb_ge_r1_r1_0[] = {
  0xa8, 0xbf, 0x49, 0x42 // It ge; rsb ge r1 r1 0
};
const byte kInstruction_rsb_ge_r1_r2_0[] = {
  0xa8, 0xbf, 0x51, 0x42 // It ge; rsb ge r1 r2 0
};
const byte kInstruction_rsb_ge_r1_r3_0[] = {
  0xa8, 0xbf, 0x59, 0x42 // It ge; rsb ge r1 r3 0
};
const byte kInstruction_rsb_ge_r1_r4_0[] = {
  0xa8, 0xbf, 0x61, 0x42 // It ge; rsb ge r1 r4 0
};
const byte kInstruction_rsb_ge_r1_r5_0[] = {
  0xa8, 0xbf, 0x69, 0x42 // It ge; rsb ge r1 r5 0
};
const byte kInstruction_rsb_ge_r1_r6_0[] = {
  0xa8, 0xbf, 0x71, 0x42 // It ge; rsb ge r1 r6 0
};
const byte kInstruction_rsb_ge_r1_r7_0[] = {
  0xa8, 0xbf, 0x79, 0x42 // It ge; rsb ge r1 r7 0
};
const byte kInstruction_rsb_ge_r2_r0_0[] = {
  0xa8, 0xbf, 0x42, 0x42 // It ge; rsb ge r2 r0 0
};
const byte kInstruction_rsb_ge_r2_r1_0[] = {
  0xa8, 0xbf, 0x4a, 0x42 // It ge; rsb ge r2 r1 0
};
const byte kInstruction_rsb_ge_r2_r2_0[] = {
  0xa8, 0xbf, 0x52, 0x42 // It ge; rsb ge r2 r2 0
};
const byte kInstruction_rsb_ge_r2_r3_0[] = {
  0xa8, 0xbf, 0x5a, 0x42 // It ge; rsb ge r2 r3 0
};
const byte kInstruction_rsb_ge_r2_r4_0[] = {
  0xa8, 0xbf, 0x62, 0x42 // It ge; rsb ge r2 r4 0
};
const byte kInstruction_rsb_ge_r2_r5_0[] = {
  0xa8, 0xbf, 0x6a, 0x42 // It ge; rsb ge r2 r5 0
};
const byte kInstruction_rsb_ge_r2_r6_0[] = {
  0xa8, 0xbf, 0x72, 0x42 // It ge; rsb ge r2 r6 0
};
const byte kInstruction_rsb_ge_r2_r7_0[] = {
  0xa8, 0xbf, 0x7a, 0x42 // It ge; rsb ge r2 r7 0
};
const byte kInstruction_rsb_ge_r3_r0_0[] = {
  0xa8, 0xbf, 0x43, 0x42 // It ge; rsb ge r3 r0 0
};
const byte kInstruction_rsb_ge_r3_r1_0[] = {
  0xa8, 0xbf, 0x4b, 0x42 // It ge; rsb ge r3 r1 0
};
const byte kInstruction_rsb_ge_r3_r2_0[] = {
  0xa8, 0xbf, 0x53, 0x42 // It ge; rsb ge r3 r2 0
};
const byte kInstruction_rsb_ge_r3_r3_0[] = {
  0xa8, 0xbf, 0x5b, 0x42 // It ge; rsb ge r3 r3 0
};
const byte kInstruction_rsb_ge_r3_r4_0[] = {
  0xa8, 0xbf, 0x63, 0x42 // It ge; rsb ge r3 r4 0
};
const byte kInstruction_rsb_ge_r3_r5_0[] = {
  0xa8, 0xbf, 0x6b, 0x42 // It ge; rsb ge r3 r5 0
};
const byte kInstruction_rsb_ge_r3_r6_0[] = {
  0xa8, 0xbf, 0x73, 0x42 // It ge; rsb ge r3 r6 0
};
const byte kInstruction_rsb_ge_r3_r7_0[] = {
  0xa8, 0xbf, 0x7b, 0x42 // It ge; rsb ge r3 r7 0
};
const byte kInstruction_rsb_ge_r4_r0_0[] = {
  0xa8, 0xbf, 0x44, 0x42 // It ge; rsb ge r4 r0 0
};
const byte kInstruction_rsb_ge_r4_r1_0[] = {
  0xa8, 0xbf, 0x4c, 0x42 // It ge; rsb ge r4 r1 0
};
const byte kInstruction_rsb_ge_r4_r2_0[] = {
  0xa8, 0xbf, 0x54, 0x42 // It ge; rsb ge r4 r2 0
};
const byte kInstruction_rsb_ge_r4_r3_0[] = {
  0xa8, 0xbf, 0x5c, 0x42 // It ge; rsb ge r4 r3 0
};
const byte kInstruction_rsb_ge_r4_r4_0[] = {
  0xa8, 0xbf, 0x64, 0x42 // It ge; rsb ge r4 r4 0
};
const byte kInstruction_rsb_ge_r4_r5_0[] = {
  0xa8, 0xbf, 0x6c, 0x42 // It ge; rsb ge r4 r5 0
};
const byte kInstruction_rsb_ge_r4_r6_0[] = {
  0xa8, 0xbf, 0x74, 0x42 // It ge; rsb ge r4 r6 0
};
const byte kInstruction_rsb_ge_r4_r7_0[] = {
  0xa8, 0xbf, 0x7c, 0x42 // It ge; rsb ge r4 r7 0
};
const byte kInstruction_rsb_ge_r5_r0_0[] = {
  0xa8, 0xbf, 0x45, 0x42 // It ge; rsb ge r5 r0 0
};
const byte kInstruction_rsb_ge_r5_r1_0[] = {
  0xa8, 0xbf, 0x4d, 0x42 // It ge; rsb ge r5 r1 0
};
const byte kInstruction_rsb_ge_r5_r2_0[] = {
  0xa8, 0xbf, 0x55, 0x42 // It ge; rsb ge r5 r2 0
};
const byte kInstruction_rsb_ge_r5_r3_0[] = {
  0xa8, 0xbf, 0x5d, 0x42 // It ge; rsb ge r5 r3 0
};
const byte kInstruction_rsb_ge_r5_r4_0[] = {
  0xa8, 0xbf, 0x65, 0x42 // It ge; rsb ge r5 r4 0
};
const byte kInstruction_rsb_ge_r5_r5_0[] = {
  0xa8, 0xbf, 0x6d, 0x42 // It ge; rsb ge r5 r5 0
};
const byte kInstruction_rsb_ge_r5_r6_0[] = {
  0xa8, 0xbf, 0x75, 0x42 // It ge; rsb ge r5 r6 0
};
const byte kInstruction_rsb_ge_r5_r7_0[] = {
  0xa8, 0xbf, 0x7d, 0x42 // It ge; rsb ge r5 r7 0
};
const byte kInstruction_rsb_ge_r6_r0_0[] = {
  0xa8, 0xbf, 0x46, 0x42 // It ge; rsb ge r6 r0 0
};
const byte kInstruction_rsb_ge_r6_r1_0[] = {
  0xa8, 0xbf, 0x4e, 0x42 // It ge; rsb ge r6 r1 0
};
const byte kInstruction_rsb_ge_r6_r2_0[] = {
  0xa8, 0xbf, 0x56, 0x42 // It ge; rsb ge r6 r2 0
};
const byte kInstruction_rsb_ge_r6_r3_0[] = {
  0xa8, 0xbf, 0x5e, 0x42 // It ge; rsb ge r6 r3 0
};
const byte kInstruction_rsb_ge_r6_r4_0[] = {
  0xa8, 0xbf, 0x66, 0x42 // It ge; rsb ge r6 r4 0
};
const byte kInstruction_rsb_ge_r6_r5_0[] = {
  0xa8, 0xbf, 0x6e, 0x42 // It ge; rsb ge r6 r5 0
};
const byte kInstruction_rsb_ge_r6_r6_0[] = {
  0xa8, 0xbf, 0x76, 0x42 // It ge; rsb ge r6 r6 0
};
const byte kInstruction_rsb_ge_r6_r7_0[] = {
  0xa8, 0xbf, 0x7e, 0x42 // It ge; rsb ge r6 r7 0
};
const byte kInstruction_rsb_ge_r7_r0_0[] = {
  0xa8, 0xbf, 0x47, 0x42 // It ge; rsb ge r7 r0 0
};
const byte kInstruction_rsb_ge_r7_r1_0[] = {
  0xa8, 0xbf, 0x4f, 0x42 // It ge; rsb ge r7 r1 0
};
const byte kInstruction_rsb_ge_r7_r2_0[] = {
  0xa8, 0xbf, 0x57, 0x42 // It ge; rsb ge r7 r2 0
};
const byte kInstruction_rsb_ge_r7_r3_0[] = {
  0xa8, 0xbf, 0x5f, 0x42 // It ge; rsb ge r7 r3 0
};
const byte kInstruction_rsb_ge_r7_r4_0[] = {
  0xa8, 0xbf, 0x67, 0x42 // It ge; rsb ge r7 r4 0
};
const byte kInstruction_rsb_ge_r7_r5_0[] = {
  0xa8, 0xbf, 0x6f, 0x42 // It ge; rsb ge r7 r5 0
};
const byte kInstruction_rsb_ge_r7_r6_0[] = {
  0xa8, 0xbf, 0x77, 0x42 // It ge; rsb ge r7 r6 0
};
const byte kInstruction_rsb_ge_r7_r7_0[] = {
  0xa8, 0xbf, 0x7f, 0x42 // It ge; rsb ge r7 r7 0
};
const byte kInstruction_rsb_lt_r0_r0_0[] = {
  0xb8, 0xbf, 0x40, 0x42 // It lt; rsb lt r0 r0 0
};
const byte kInstruction_rsb_lt_r0_r1_0[] = {
  0xb8, 0xbf, 0x48, 0x42 // It lt; rsb lt r0 r1 0
};
const byte kInstruction_rsb_lt_r0_r2_0[] = {
  0xb8, 0xbf, 0x50, 0x42 // It lt; rsb lt r0 r2 0
};
const byte kInstruction_rsb_lt_r0_r3_0[] = {
  0xb8, 0xbf, 0x58, 0x42 // It lt; rsb lt r0 r3 0
};
const byte kInstruction_rsb_lt_r0_r4_0[] = {
  0xb8, 0xbf, 0x60, 0x42 // It lt; rsb lt r0 r4 0
};
const byte kInstruction_rsb_lt_r0_r5_0[] = {
  0xb8, 0xbf, 0x68, 0x42 // It lt; rsb lt r0 r5 0
};
const byte kInstruction_rsb_lt_r0_r6_0[] = {
  0xb8, 0xbf, 0x70, 0x42 // It lt; rsb lt r0 r6 0
};
const byte kInstruction_rsb_lt_r0_r7_0[] = {
  0xb8, 0xbf, 0x78, 0x42 // It lt; rsb lt r0 r7 0
};
const byte kInstruction_rsb_lt_r1_r0_0[] = {
  0xb8, 0xbf, 0x41, 0x42 // It lt; rsb lt r1 r0 0
};
const byte kInstruction_rsb_lt_r1_r1_0[] = {
  0xb8, 0xbf, 0x49, 0x42 // It lt; rsb lt r1 r1 0
};
const byte kInstruction_rsb_lt_r1_r2_0[] = {
  0xb8, 0xbf, 0x51, 0x42 // It lt; rsb lt r1 r2 0
};
const byte kInstruction_rsb_lt_r1_r3_0[] = {
  0xb8, 0xbf, 0x59, 0x42 // It lt; rsb lt r1 r3 0
};
const byte kInstruction_rsb_lt_r1_r4_0[] = {
  0xb8, 0xbf, 0x61, 0x42 // It lt; rsb lt r1 r4 0
};
const byte kInstruction_rsb_lt_r1_r5_0[] = {
  0xb8, 0xbf, 0x69, 0x42 // It lt; rsb lt r1 r5 0
};
const byte kInstruction_rsb_lt_r1_r6_0[] = {
  0xb8, 0xbf, 0x71, 0x42 // It lt; rsb lt r1 r6 0
};
const byte kInstruction_rsb_lt_r1_r7_0[] = {
  0xb8, 0xbf, 0x79, 0x42 // It lt; rsb lt r1 r7 0
};
const byte kInstruction_rsb_lt_r2_r0_0[] = {
  0xb8, 0xbf, 0x42, 0x42 // It lt; rsb lt r2 r0 0
};
const byte kInstruction_rsb_lt_r2_r1_0[] = {
  0xb8, 0xbf, 0x4a, 0x42 // It lt; rsb lt r2 r1 0
};
const byte kInstruction_rsb_lt_r2_r2_0[] = {
  0xb8, 0xbf, 0x52, 0x42 // It lt; rsb lt r2 r2 0
};
const byte kInstruction_rsb_lt_r2_r3_0[] = {
  0xb8, 0xbf, 0x5a, 0x42 // It lt; rsb lt r2 r3 0
};
const byte kInstruction_rsb_lt_r2_r4_0[] = {
  0xb8, 0xbf, 0x62, 0x42 // It lt; rsb lt r2 r4 0
};
const byte kInstruction_rsb_lt_r2_r5_0[] = {
  0xb8, 0xbf, 0x6a, 0x42 // It lt; rsb lt r2 r5 0
};
const byte kInstruction_rsb_lt_r2_r6_0[] = {
  0xb8, 0xbf, 0x72, 0x42 // It lt; rsb lt r2 r6 0
};
const byte kInstruction_rsb_lt_r2_r7_0[] = {
  0xb8, 0xbf, 0x7a, 0x42 // It lt; rsb lt r2 r7 0
};
const byte kInstruction_rsb_lt_r3_r0_0[] = {
  0xb8, 0xbf, 0x43, 0x42 // It lt; rsb lt r3 r0 0
};
const byte kInstruction_rsb_lt_r3_r1_0[] = {
  0xb8, 0xbf, 0x4b, 0x42 // It lt; rsb lt r3 r1 0
};
const byte kInstruction_rsb_lt_r3_r2_0[] = {
  0xb8, 0xbf, 0x53, 0x42 // It lt; rsb lt r3 r2 0
};
const byte kInstruction_rsb_lt_r3_r3_0[] = {
  0xb8, 0xbf, 0x5b, 0x42 // It lt; rsb lt r3 r3 0
};
const byte kInstruction_rsb_lt_r3_r4_0[] = {
  0xb8, 0xbf, 0x63, 0x42 // It lt; rsb lt r3 r4 0
};
const byte kInstruction_rsb_lt_r3_r5_0[] = {
  0xb8, 0xbf, 0x6b, 0x42 // It lt; rsb lt r3 r5 0
};
const byte kInstruction_rsb_lt_r3_r6_0[] = {
  0xb8, 0xbf, 0x73, 0x42 // It lt; rsb lt r3 r6 0
};
const byte kInstruction_rsb_lt_r3_r7_0[] = {
  0xb8, 0xbf, 0x7b, 0x42 // It lt; rsb lt r3 r7 0
};
const byte kInstruction_rsb_lt_r4_r0_0[] = {
  0xb8, 0xbf, 0x44, 0x42 // It lt; rsb lt r4 r0 0
};
const byte kInstruction_rsb_lt_r4_r1_0[] = {
  0xb8, 0xbf, 0x4c, 0x42 // It lt; rsb lt r4 r1 0
};
const byte kInstruction_rsb_lt_r4_r2_0[] = {
  0xb8, 0xbf, 0x54, 0x42 // It lt; rsb lt r4 r2 0
};
const byte kInstruction_rsb_lt_r4_r3_0[] = {
  0xb8, 0xbf, 0x5c, 0x42 // It lt; rsb lt r4 r3 0
};
const byte kInstruction_rsb_lt_r4_r4_0[] = {
  0xb8, 0xbf, 0x64, 0x42 // It lt; rsb lt r4 r4 0
};
const byte kInstruction_rsb_lt_r4_r5_0[] = {
  0xb8, 0xbf, 0x6c, 0x42 // It lt; rsb lt r4 r5 0
};
const byte kInstruction_rsb_lt_r4_r6_0[] = {
  0xb8, 0xbf, 0x74, 0x42 // It lt; rsb lt r4 r6 0
};
const byte kInstruction_rsb_lt_r4_r7_0[] = {
  0xb8, 0xbf, 0x7c, 0x42 // It lt; rsb lt r4 r7 0
};
const byte kInstruction_rsb_lt_r5_r0_0[] = {
  0xb8, 0xbf, 0x45, 0x42 // It lt; rsb lt r5 r0 0
};
const byte kInstruction_rsb_lt_r5_r1_0[] = {
  0xb8, 0xbf, 0x4d, 0x42 // It lt; rsb lt r5 r1 0
};
const byte kInstruction_rsb_lt_r5_r2_0[] = {
  0xb8, 0xbf, 0x55, 0x42 // It lt; rsb lt r5 r2 0
};
const byte kInstruction_rsb_lt_r5_r3_0[] = {
  0xb8, 0xbf, 0x5d, 0x42 // It lt; rsb lt r5 r3 0
};
const byte kInstruction_rsb_lt_r5_r4_0[] = {
  0xb8, 0xbf, 0x65, 0x42 // It lt; rsb lt r5 r4 0
};
const byte kInstruction_rsb_lt_r5_r5_0[] = {
  0xb8, 0xbf, 0x6d, 0x42 // It lt; rsb lt r5 r5 0
};
const byte kInstruction_rsb_lt_r5_r6_0[] = {
  0xb8, 0xbf, 0x75, 0x42 // It lt; rsb lt r5 r6 0
};
const byte kInstruction_rsb_lt_r5_r7_0[] = {
  0xb8, 0xbf, 0x7d, 0x42 // It lt; rsb lt r5 r7 0
};
const byte kInstruction_rsb_lt_r6_r0_0[] = {
  0xb8, 0xbf, 0x46, 0x42 // It lt; rsb lt r6 r0 0
};
const byte kInstruction_rsb_lt_r6_r1_0[] = {
  0xb8, 0xbf, 0x4e, 0x42 // It lt; rsb lt r6 r1 0
};
const byte kInstruction_rsb_lt_r6_r2_0[] = {
  0xb8, 0xbf, 0x56, 0x42 // It lt; rsb lt r6 r2 0
};
const byte kInstruction_rsb_lt_r6_r3_0[] = {
  0xb8, 0xbf, 0x5e, 0x42 // It lt; rsb lt r6 r3 0
};
const byte kInstruction_rsb_lt_r6_r4_0[] = {
  0xb8, 0xbf, 0x66, 0x42 // It lt; rsb lt r6 r4 0
};
const byte kInstruction_rsb_lt_r6_r5_0[] = {
  0xb8, 0xbf, 0x6e, 0x42 // It lt; rsb lt r6 r5 0
};
const byte kInstruction_rsb_lt_r6_r6_0[] = {
  0xb8, 0xbf, 0x76, 0x42 // It lt; rsb lt r6 r6 0
};
const byte kInstruction_rsb_lt_r6_r7_0[] = {
  0xb8, 0xbf, 0x7e, 0x42 // It lt; rsb lt r6 r7 0
};
const byte kInstruction_rsb_lt_r7_r0_0[] = {
  0xb8, 0xbf, 0x47, 0x42 // It lt; rsb lt r7 r0 0
};
const byte kInstruction_rsb_lt_r7_r1_0[] = {
  0xb8, 0xbf, 0x4f, 0x42 // It lt; rsb lt r7 r1 0
};
const byte kInstruction_rsb_lt_r7_r2_0[] = {
  0xb8, 0xbf, 0x57, 0x42 // It lt; rsb lt r7 r2 0
};
const byte kInstruction_rsb_lt_r7_r3_0[] = {
  0xb8, 0xbf, 0x5f, 0x42 // It lt; rsb lt r7 r3 0
};
const byte kInstruction_rsb_lt_r7_r4_0[] = {
  0xb8, 0xbf, 0x67, 0x42 // It lt; rsb lt r7 r4 0
};
const byte kInstruction_rsb_lt_r7_r5_0[] = {
  0xb8, 0xbf, 0x6f, 0x42 // It lt; rsb lt r7 r5 0
};
const byte kInstruction_rsb_lt_r7_r6_0[] = {
  0xb8, 0xbf, 0x77, 0x42 // It lt; rsb lt r7 r6 0
};
const byte kInstruction_rsb_lt_r7_r7_0[] = {
  0xb8, 0xbf, 0x7f, 0x42 // It lt; rsb lt r7 r7 0
};
const byte kInstruction_rsb_gt_r0_r0_0[] = {
  0xc8, 0xbf, 0x40, 0x42 // It gt; rsb gt r0 r0 0
};
const byte kInstruction_rsb_gt_r0_r1_0[] = {
  0xc8, 0xbf, 0x48, 0x42 // It gt; rsb gt r0 r1 0
};
const byte kInstruction_rsb_gt_r0_r2_0[] = {
  0xc8, 0xbf, 0x50, 0x42 // It gt; rsb gt r0 r2 0
};
const byte kInstruction_rsb_gt_r0_r3_0[] = {
  0xc8, 0xbf, 0x58, 0x42 // It gt; rsb gt r0 r3 0
};
const byte kInstruction_rsb_gt_r0_r4_0[] = {
  0xc8, 0xbf, 0x60, 0x42 // It gt; rsb gt r0 r4 0
};
const byte kInstruction_rsb_gt_r0_r5_0[] = {
  0xc8, 0xbf, 0x68, 0x42 // It gt; rsb gt r0 r5 0
};
const byte kInstruction_rsb_gt_r0_r6_0[] = {
  0xc8, 0xbf, 0x70, 0x42 // It gt; rsb gt r0 r6 0
};
const byte kInstruction_rsb_gt_r0_r7_0[] = {
  0xc8, 0xbf, 0x78, 0x42 // It gt; rsb gt r0 r7 0
};
const byte kInstruction_rsb_gt_r1_r0_0[] = {
  0xc8, 0xbf, 0x41, 0x42 // It gt; rsb gt r1 r0 0
};
const byte kInstruction_rsb_gt_r1_r1_0[] = {
  0xc8, 0xbf, 0x49, 0x42 // It gt; rsb gt r1 r1 0
};
const byte kInstruction_rsb_gt_r1_r2_0[] = {
  0xc8, 0xbf, 0x51, 0x42 // It gt; rsb gt r1 r2 0
};
const byte kInstruction_rsb_gt_r1_r3_0[] = {
  0xc8, 0xbf, 0x59, 0x42 // It gt; rsb gt r1 r3 0
};
const byte kInstruction_rsb_gt_r1_r4_0[] = {
  0xc8, 0xbf, 0x61, 0x42 // It gt; rsb gt r1 r4 0
};
const byte kInstruction_rsb_gt_r1_r5_0[] = {
  0xc8, 0xbf, 0x69, 0x42 // It gt; rsb gt r1 r5 0
};
const byte kInstruction_rsb_gt_r1_r6_0[] = {
  0xc8, 0xbf, 0x71, 0x42 // It gt; rsb gt r1 r6 0
};
const byte kInstruction_rsb_gt_r1_r7_0[] = {
  0xc8, 0xbf, 0x79, 0x42 // It gt; rsb gt r1 r7 0
};
const byte kInstruction_rsb_gt_r2_r0_0[] = {
  0xc8, 0xbf, 0x42, 0x42 // It gt; rsb gt r2 r0 0
};
const byte kInstruction_rsb_gt_r2_r1_0[] = {
  0xc8, 0xbf, 0x4a, 0x42 // It gt; rsb gt r2 r1 0
};
const byte kInstruction_rsb_gt_r2_r2_0[] = {
  0xc8, 0xbf, 0x52, 0x42 // It gt; rsb gt r2 r2 0
};
const byte kInstruction_rsb_gt_r2_r3_0[] = {
  0xc8, 0xbf, 0x5a, 0x42 // It gt; rsb gt r2 r3 0
};
const byte kInstruction_rsb_gt_r2_r4_0[] = {
  0xc8, 0xbf, 0x62, 0x42 // It gt; rsb gt r2 r4 0
};
const byte kInstruction_rsb_gt_r2_r5_0[] = {
  0xc8, 0xbf, 0x6a, 0x42 // It gt; rsb gt r2 r5 0
};
const byte kInstruction_rsb_gt_r2_r6_0[] = {
  0xc8, 0xbf, 0x72, 0x42 // It gt; rsb gt r2 r6 0
};
const byte kInstruction_rsb_gt_r2_r7_0[] = {
  0xc8, 0xbf, 0x7a, 0x42 // It gt; rsb gt r2 r7 0
};
const byte kInstruction_rsb_gt_r3_r0_0[] = {
  0xc8, 0xbf, 0x43, 0x42 // It gt; rsb gt r3 r0 0
};
const byte kInstruction_rsb_gt_r3_r1_0[] = {
  0xc8, 0xbf, 0x4b, 0x42 // It gt; rsb gt r3 r1 0
};
const byte kInstruction_rsb_gt_r3_r2_0[] = {
  0xc8, 0xbf, 0x53, 0x42 // It gt; rsb gt r3 r2 0
};
const byte kInstruction_rsb_gt_r3_r3_0[] = {
  0xc8, 0xbf, 0x5b, 0x42 // It gt; rsb gt r3 r3 0
};
const byte kInstruction_rsb_gt_r3_r4_0[] = {
  0xc8, 0xbf, 0x63, 0x42 // It gt; rsb gt r3 r4 0
};
const byte kInstruction_rsb_gt_r3_r5_0[] = {
  0xc8, 0xbf, 0x6b, 0x42 // It gt; rsb gt r3 r5 0
};
const byte kInstruction_rsb_gt_r3_r6_0[] = {
  0xc8, 0xbf, 0x73, 0x42 // It gt; rsb gt r3 r6 0
};
const byte kInstruction_rsb_gt_r3_r7_0[] = {
  0xc8, 0xbf, 0x7b, 0x42 // It gt; rsb gt r3 r7 0
};
const byte kInstruction_rsb_gt_r4_r0_0[] = {
  0xc8, 0xbf, 0x44, 0x42 // It gt; rsb gt r4 r0 0
};
const byte kInstruction_rsb_gt_r4_r1_0[] = {
  0xc8, 0xbf, 0x4c, 0x42 // It gt; rsb gt r4 r1 0
};
const byte kInstruction_rsb_gt_r4_r2_0[] = {
  0xc8, 0xbf, 0x54, 0x42 // It gt; rsb gt r4 r2 0
};
const byte kInstruction_rsb_gt_r4_r3_0[] = {
  0xc8, 0xbf, 0x5c, 0x42 // It gt; rsb gt r4 r3 0
};
const byte kInstruction_rsb_gt_r4_r4_0[] = {
  0xc8, 0xbf, 0x64, 0x42 // It gt; rsb gt r4 r4 0
};
const byte kInstruction_rsb_gt_r4_r5_0[] = {
  0xc8, 0xbf, 0x6c, 0x42 // It gt; rsb gt r4 r5 0
};
const byte kInstruction_rsb_gt_r4_r6_0[] = {
  0xc8, 0xbf, 0x74, 0x42 // It gt; rsb gt r4 r6 0
};
const byte kInstruction_rsb_gt_r4_r7_0[] = {
  0xc8, 0xbf, 0x7c, 0x42 // It gt; rsb gt r4 r7 0
};
const byte kInstruction_rsb_gt_r5_r0_0[] = {
  0xc8, 0xbf, 0x45, 0x42 // It gt; rsb gt r5 r0 0
};
const byte kInstruction_rsb_gt_r5_r1_0[] = {
  0xc8, 0xbf, 0x4d, 0x42 // It gt; rsb gt r5 r1 0
};
const byte kInstruction_rsb_gt_r5_r2_0[] = {
  0xc8, 0xbf, 0x55, 0x42 // It gt; rsb gt r5 r2 0
};
const byte kInstruction_rsb_gt_r5_r3_0[] = {
  0xc8, 0xbf, 0x5d, 0x42 // It gt; rsb gt r5 r3 0
};
const byte kInstruction_rsb_gt_r5_r4_0[] = {
  0xc8, 0xbf, 0x65, 0x42 // It gt; rsb gt r5 r4 0
};
const byte kInstruction_rsb_gt_r5_r5_0[] = {
  0xc8, 0xbf, 0x6d, 0x42 // It gt; rsb gt r5 r5 0
};
const byte kInstruction_rsb_gt_r5_r6_0[] = {
  0xc8, 0xbf, 0x75, 0x42 // It gt; rsb gt r5 r6 0
};
const byte kInstruction_rsb_gt_r5_r7_0[] = {
  0xc8, 0xbf, 0x7d, 0x42 // It gt; rsb gt r5 r7 0
};
const byte kInstruction_rsb_gt_r6_r0_0[] = {
  0xc8, 0xbf, 0x46, 0x42 // It gt; rsb gt r6 r0 0
};
const byte kInstruction_rsb_gt_r6_r1_0[] = {
  0xc8, 0xbf, 0x4e, 0x42 // It gt; rsb gt r6 r1 0
};
const byte kInstruction_rsb_gt_r6_r2_0[] = {
  0xc8, 0xbf, 0x56, 0x42 // It gt; rsb gt r6 r2 0
};
const byte kInstruction_rsb_gt_r6_r3_0[] = {
  0xc8, 0xbf, 0x5e, 0x42 // It gt; rsb gt r6 r3 0
};
const byte kInstruction_rsb_gt_r6_r4_0[] = {
  0xc8, 0xbf, 0x66, 0x42 // It gt; rsb gt r6 r4 0
};
const byte kInstruction_rsb_gt_r6_r5_0[] = {
  0xc8, 0xbf, 0x6e, 0x42 // It gt; rsb gt r6 r5 0
};
const byte kInstruction_rsb_gt_r6_r6_0[] = {
  0xc8, 0xbf, 0x76, 0x42 // It gt; rsb gt r6 r6 0
};
const byte kInstruction_rsb_gt_r6_r7_0[] = {
  0xc8, 0xbf, 0x7e, 0x42 // It gt; rsb gt r6 r7 0
};
const byte kInstruction_rsb_gt_r7_r0_0[] = {
  0xc8, 0xbf, 0x47, 0x42 // It gt; rsb gt r7 r0 0
};
const byte kInstruction_rsb_gt_r7_r1_0[] = {
  0xc8, 0xbf, 0x4f, 0x42 // It gt; rsb gt r7 r1 0
};
const byte kInstruction_rsb_gt_r7_r2_0[] = {
  0xc8, 0xbf, 0x57, 0x42 // It gt; rsb gt r7 r2 0
};
const byte kInstruction_rsb_gt_r7_r3_0[] = {
  0xc8, 0xbf, 0x5f, 0x42 // It gt; rsb gt r7 r3 0
};
const byte kInstruction_rsb_gt_r7_r4_0[] = {
  0xc8, 0xbf, 0x67, 0x42 // It gt; rsb gt r7 r4 0
};
const byte kInstruction_rsb_gt_r7_r5_0[] = {
  0xc8, 0xbf, 0x6f, 0x42 // It gt; rsb gt r7 r5 0
};
const byte kInstruction_rsb_gt_r7_r6_0[] = {
  0xc8, 0xbf, 0x77, 0x42 // It gt; rsb gt r7 r6 0
};
const byte kInstruction_rsb_gt_r7_r7_0[] = {
  0xc8, 0xbf, 0x7f, 0x42 // It gt; rsb gt r7 r7 0
};
const byte kInstruction_rsb_le_r0_r0_0[] = {
  0xd8, 0xbf, 0x40, 0x42 // It le; rsb le r0 r0 0
};
const byte kInstruction_rsb_le_r0_r1_0[] = {
  0xd8, 0xbf, 0x48, 0x42 // It le; rsb le r0 r1 0
};
const byte kInstruction_rsb_le_r0_r2_0[] = {
  0xd8, 0xbf, 0x50, 0x42 // It le; rsb le r0 r2 0
};
const byte kInstruction_rsb_le_r0_r3_0[] = {
  0xd8, 0xbf, 0x58, 0x42 // It le; rsb le r0 r3 0
};
const byte kInstruction_rsb_le_r0_r4_0[] = {
  0xd8, 0xbf, 0x60, 0x42 // It le; rsb le r0 r4 0
};
const byte kInstruction_rsb_le_r0_r5_0[] = {
  0xd8, 0xbf, 0x68, 0x42 // It le; rsb le r0 r5 0
};
const byte kInstruction_rsb_le_r0_r6_0[] = {
  0xd8, 0xbf, 0x70, 0x42 // It le; rsb le r0 r6 0
};
const byte kInstruction_rsb_le_r0_r7_0[] = {
  0xd8, 0xbf, 0x78, 0x42 // It le; rsb le r0 r7 0
};
const byte kInstruction_rsb_le_r1_r0_0[] = {
  0xd8, 0xbf, 0x41, 0x42 // It le; rsb le r1 r0 0
};
const byte kInstruction_rsb_le_r1_r1_0[] = {
  0xd8, 0xbf, 0x49, 0x42 // It le; rsb le r1 r1 0
};
const byte kInstruction_rsb_le_r1_r2_0[] = {
  0xd8, 0xbf, 0x51, 0x42 // It le; rsb le r1 r2 0
};
const byte kInstruction_rsb_le_r1_r3_0[] = {
  0xd8, 0xbf, 0x59, 0x42 // It le; rsb le r1 r3 0
};
const byte kInstruction_rsb_le_r1_r4_0[] = {
  0xd8, 0xbf, 0x61, 0x42 // It le; rsb le r1 r4 0
};
const byte kInstruction_rsb_le_r1_r5_0[] = {
  0xd8, 0xbf, 0x69, 0x42 // It le; rsb le r1 r5 0
};
const byte kInstruction_rsb_le_r1_r6_0[] = {
  0xd8, 0xbf, 0x71, 0x42 // It le; rsb le r1 r6 0
};
const byte kInstruction_rsb_le_r1_r7_0[] = {
  0xd8, 0xbf, 0x79, 0x42 // It le; rsb le r1 r7 0
};
const byte kInstruction_rsb_le_r2_r0_0[] = {
  0xd8, 0xbf, 0x42, 0x42 // It le; rsb le r2 r0 0
};
const byte kInstruction_rsb_le_r2_r1_0[] = {
  0xd8, 0xbf, 0x4a, 0x42 // It le; rsb le r2 r1 0
};
const byte kInstruction_rsb_le_r2_r2_0[] = {
  0xd8, 0xbf, 0x52, 0x42 // It le; rsb le r2 r2 0
};
const byte kInstruction_rsb_le_r2_r3_0[] = {
  0xd8, 0xbf, 0x5a, 0x42 // It le; rsb le r2 r3 0
};
const byte kInstruction_rsb_le_r2_r4_0[] = {
  0xd8, 0xbf, 0x62, 0x42 // It le; rsb le r2 r4 0
};
const byte kInstruction_rsb_le_r2_r5_0[] = {
  0xd8, 0xbf, 0x6a, 0x42 // It le; rsb le r2 r5 0
};
const byte kInstruction_rsb_le_r2_r6_0[] = {
  0xd8, 0xbf, 0x72, 0x42 // It le; rsb le r2 r6 0
};
const byte kInstruction_rsb_le_r2_r7_0[] = {
  0xd8, 0xbf, 0x7a, 0x42 // It le; rsb le r2 r7 0
};
const byte kInstruction_rsb_le_r3_r0_0[] = {
  0xd8, 0xbf, 0x43, 0x42 // It le; rsb le r3 r0 0
};
const byte kInstruction_rsb_le_r3_r1_0[] = {
  0xd8, 0xbf, 0x4b, 0x42 // It le; rsb le r3 r1 0
};
const byte kInstruction_rsb_le_r3_r2_0[] = {
  0xd8, 0xbf, 0x53, 0x42 // It le; rsb le r3 r2 0
};
const byte kInstruction_rsb_le_r3_r3_0[] = {
  0xd8, 0xbf, 0x5b, 0x42 // It le; rsb le r3 r3 0
};
const byte kInstruction_rsb_le_r3_r4_0[] = {
  0xd8, 0xbf, 0x63, 0x42 // It le; rsb le r3 r4 0
};
const byte kInstruction_rsb_le_r3_r5_0[] = {
  0xd8, 0xbf, 0x6b, 0x42 // It le; rsb le r3 r5 0
};
const byte kInstruction_rsb_le_r3_r6_0[] = {
  0xd8, 0xbf, 0x73, 0x42 // It le; rsb le r3 r6 0
};
const byte kInstruction_rsb_le_r3_r7_0[] = {
  0xd8, 0xbf, 0x7b, 0x42 // It le; rsb le r3 r7 0
};
const byte kInstruction_rsb_le_r4_r0_0[] = {
  0xd8, 0xbf, 0x44, 0x42 // It le; rsb le r4 r0 0
};
const byte kInstruction_rsb_le_r4_r1_0[] = {
  0xd8, 0xbf, 0x4c, 0x42 // It le; rsb le r4 r1 0
};
const byte kInstruction_rsb_le_r4_r2_0[] = {
  0xd8, 0xbf, 0x54, 0x42 // It le; rsb le r4 r2 0
};
const byte kInstruction_rsb_le_r4_r3_0[] = {
  0xd8, 0xbf, 0x5c, 0x42 // It le; rsb le r4 r3 0
};
const byte kInstruction_rsb_le_r4_r4_0[] = {
  0xd8, 0xbf, 0x64, 0x42 // It le; rsb le r4 r4 0
};
const byte kInstruction_rsb_le_r4_r5_0[] = {
  0xd8, 0xbf, 0x6c, 0x42 // It le; rsb le r4 r5 0
};
const byte kInstruction_rsb_le_r4_r6_0[] = {
  0xd8, 0xbf, 0x74, 0x42 // It le; rsb le r4 r6 0
};
const byte kInstruction_rsb_le_r4_r7_0[] = {
  0xd8, 0xbf, 0x7c, 0x42 // It le; rsb le r4 r7 0
};
const byte kInstruction_rsb_le_r5_r0_0[] = {
  0xd8, 0xbf, 0x45, 0x42 // It le; rsb le r5 r0 0
};
const byte kInstruction_rsb_le_r5_r1_0[] = {
  0xd8, 0xbf, 0x4d, 0x42 // It le; rsb le r5 r1 0
};
const byte kInstruction_rsb_le_r5_r2_0[] = {
  0xd8, 0xbf, 0x55, 0x42 // It le; rsb le r5 r2 0
};
const byte kInstruction_rsb_le_r5_r3_0[] = {
  0xd8, 0xbf, 0x5d, 0x42 // It le; rsb le r5 r3 0
};
const byte kInstruction_rsb_le_r5_r4_0[] = {
  0xd8, 0xbf, 0x65, 0x42 // It le; rsb le r5 r4 0
};
const byte kInstruction_rsb_le_r5_r5_0[] = {
  0xd8, 0xbf, 0x6d, 0x42 // It le; rsb le r5 r5 0
};
const byte kInstruction_rsb_le_r5_r6_0[] = {
  0xd8, 0xbf, 0x75, 0x42 // It le; rsb le r5 r6 0
};
const byte kInstruction_rsb_le_r5_r7_0[] = {
  0xd8, 0xbf, 0x7d, 0x42 // It le; rsb le r5 r7 0
};
const byte kInstruction_rsb_le_r6_r0_0[] = {
  0xd8, 0xbf, 0x46, 0x42 // It le; rsb le r6 r0 0
};
const byte kInstruction_rsb_le_r6_r1_0[] = {
  0xd8, 0xbf, 0x4e, 0x42 // It le; rsb le r6 r1 0
};
const byte kInstruction_rsb_le_r6_r2_0[] = {
  0xd8, 0xbf, 0x56, 0x42 // It le; rsb le r6 r2 0
};
const byte kInstruction_rsb_le_r6_r3_0[] = {
  0xd8, 0xbf, 0x5e, 0x42 // It le; rsb le r6 r3 0
};
const byte kInstruction_rsb_le_r6_r4_0[] = {
  0xd8, 0xbf, 0x66, 0x42 // It le; rsb le r6 r4 0
};
const byte kInstruction_rsb_le_r6_r5_0[] = {
  0xd8, 0xbf, 0x6e, 0x42 // It le; rsb le r6 r5 0
};
const byte kInstruction_rsb_le_r6_r6_0[] = {
  0xd8, 0xbf, 0x76, 0x42 // It le; rsb le r6 r6 0
};
const byte kInstruction_rsb_le_r6_r7_0[] = {
  0xd8, 0xbf, 0x7e, 0x42 // It le; rsb le r6 r7 0
};
const byte kInstruction_rsb_le_r7_r0_0[] = {
  0xd8, 0xbf, 0x47, 0x42 // It le; rsb le r7 r0 0
};
const byte kInstruction_rsb_le_r7_r1_0[] = {
  0xd8, 0xbf, 0x4f, 0x42 // It le; rsb le r7 r1 0
};
const byte kInstruction_rsb_le_r7_r2_0[] = {
  0xd8, 0xbf, 0x57, 0x42 // It le; rsb le r7 r2 0
};
const byte kInstruction_rsb_le_r7_r3_0[] = {
  0xd8, 0xbf, 0x5f, 0x42 // It le; rsb le r7 r3 0
};
const byte kInstruction_rsb_le_r7_r4_0[] = {
  0xd8, 0xbf, 0x67, 0x42 // It le; rsb le r7 r4 0
};
const byte kInstruction_rsb_le_r7_r5_0[] = {
  0xd8, 0xbf, 0x6f, 0x42 // It le; rsb le r7 r5 0
};
const byte kInstruction_rsb_le_r7_r6_0[] = {
  0xd8, 0xbf, 0x77, 0x42 // It le; rsb le r7 r6 0
};
const byte kInstruction_rsb_le_r7_r7_0[] = {
  0xd8, 0xbf, 0x7f, 0x42 // It le; rsb le r7 r7 0
};
const TestResult kReferencersb[] = {
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r0_0),
    kInstruction_rsb_eq_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r1_0),
    kInstruction_rsb_eq_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r2_0),
    kInstruction_rsb_eq_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r3_0),
    kInstruction_rsb_eq_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r4_0),
    kInstruction_rsb_eq_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r5_0),
    kInstruction_rsb_eq_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r6_0),
    kInstruction_rsb_eq_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r0_r7_0),
    kInstruction_rsb_eq_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r0_0),
    kInstruction_rsb_eq_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r1_0),
    kInstruction_rsb_eq_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r2_0),
    kInstruction_rsb_eq_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r3_0),
    kInstruction_rsb_eq_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r4_0),
    kInstruction_rsb_eq_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r5_0),
    kInstruction_rsb_eq_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r6_0),
    kInstruction_rsb_eq_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r1_r7_0),
    kInstruction_rsb_eq_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r0_0),
    kInstruction_rsb_eq_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r1_0),
    kInstruction_rsb_eq_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r2_0),
    kInstruction_rsb_eq_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r3_0),
    kInstruction_rsb_eq_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r4_0),
    kInstruction_rsb_eq_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r5_0),
    kInstruction_rsb_eq_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r6_0),
    kInstruction_rsb_eq_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r2_r7_0),
    kInstruction_rsb_eq_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r0_0),
    kInstruction_rsb_eq_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r1_0),
    kInstruction_rsb_eq_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r2_0),
    kInstruction_rsb_eq_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r3_0),
    kInstruction_rsb_eq_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r4_0),
    kInstruction_rsb_eq_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r5_0),
    kInstruction_rsb_eq_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r6_0),
    kInstruction_rsb_eq_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r3_r7_0),
    kInstruction_rsb_eq_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r0_0),
    kInstruction_rsb_eq_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r1_0),
    kInstruction_rsb_eq_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r2_0),
    kInstruction_rsb_eq_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r3_0),
    kInstruction_rsb_eq_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r4_0),
    kInstruction_rsb_eq_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r5_0),
    kInstruction_rsb_eq_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r6_0),
    kInstruction_rsb_eq_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r4_r7_0),
    kInstruction_rsb_eq_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r0_0),
    kInstruction_rsb_eq_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r1_0),
    kInstruction_rsb_eq_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r2_0),
    kInstruction_rsb_eq_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r3_0),
    kInstruction_rsb_eq_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r4_0),
    kInstruction_rsb_eq_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r5_0),
    kInstruction_rsb_eq_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r6_0),
    kInstruction_rsb_eq_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r5_r7_0),
    kInstruction_rsb_eq_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r0_0),
    kInstruction_rsb_eq_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r1_0),
    kInstruction_rsb_eq_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r2_0),
    kInstruction_rsb_eq_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r3_0),
    kInstruction_rsb_eq_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r4_0),
    kInstruction_rsb_eq_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r5_0),
    kInstruction_rsb_eq_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r6_0),
    kInstruction_rsb_eq_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r6_r7_0),
    kInstruction_rsb_eq_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r0_0),
    kInstruction_rsb_eq_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r1_0),
    kInstruction_rsb_eq_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r2_0),
    kInstruction_rsb_eq_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r3_0),
    kInstruction_rsb_eq_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r4_0),
    kInstruction_rsb_eq_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r5_0),
    kInstruction_rsb_eq_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r6_0),
    kInstruction_rsb_eq_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_eq_r7_r7_0),
    kInstruction_rsb_eq_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r0_0),
    kInstruction_rsb_ne_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r1_0),
    kInstruction_rsb_ne_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r2_0),
    kInstruction_rsb_ne_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r3_0),
    kInstruction_rsb_ne_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r4_0),
    kInstruction_rsb_ne_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r5_0),
    kInstruction_rsb_ne_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r6_0),
    kInstruction_rsb_ne_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r0_r7_0),
    kInstruction_rsb_ne_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r0_0),
    kInstruction_rsb_ne_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r1_0),
    kInstruction_rsb_ne_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r2_0),
    kInstruction_rsb_ne_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r3_0),
    kInstruction_rsb_ne_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r4_0),
    kInstruction_rsb_ne_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r5_0),
    kInstruction_rsb_ne_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r6_0),
    kInstruction_rsb_ne_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r1_r7_0),
    kInstruction_rsb_ne_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r0_0),
    kInstruction_rsb_ne_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r1_0),
    kInstruction_rsb_ne_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r2_0),
    kInstruction_rsb_ne_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r3_0),
    kInstruction_rsb_ne_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r4_0),
    kInstruction_rsb_ne_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r5_0),
    kInstruction_rsb_ne_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r6_0),
    kInstruction_rsb_ne_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r2_r7_0),
    kInstruction_rsb_ne_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r0_0),
    kInstruction_rsb_ne_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r1_0),
    kInstruction_rsb_ne_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r2_0),
    kInstruction_rsb_ne_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r3_0),
    kInstruction_rsb_ne_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r4_0),
    kInstruction_rsb_ne_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r5_0),
    kInstruction_rsb_ne_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r6_0),
    kInstruction_rsb_ne_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r3_r7_0),
    kInstruction_rsb_ne_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r0_0),
    kInstruction_rsb_ne_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r1_0),
    kInstruction_rsb_ne_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r2_0),
    kInstruction_rsb_ne_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r3_0),
    kInstruction_rsb_ne_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r4_0),
    kInstruction_rsb_ne_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r5_0),
    kInstruction_rsb_ne_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r6_0),
    kInstruction_rsb_ne_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r4_r7_0),
    kInstruction_rsb_ne_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r0_0),
    kInstruction_rsb_ne_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r1_0),
    kInstruction_rsb_ne_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r2_0),
    kInstruction_rsb_ne_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r3_0),
    kInstruction_rsb_ne_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r4_0),
    kInstruction_rsb_ne_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r5_0),
    kInstruction_rsb_ne_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r6_0),
    kInstruction_rsb_ne_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r5_r7_0),
    kInstruction_rsb_ne_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r0_0),
    kInstruction_rsb_ne_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r1_0),
    kInstruction_rsb_ne_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r2_0),
    kInstruction_rsb_ne_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r3_0),
    kInstruction_rsb_ne_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r4_0),
    kInstruction_rsb_ne_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r5_0),
    kInstruction_rsb_ne_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r6_0),
    kInstruction_rsb_ne_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r6_r7_0),
    kInstruction_rsb_ne_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r0_0),
    kInstruction_rsb_ne_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r1_0),
    kInstruction_rsb_ne_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r2_0),
    kInstruction_rsb_ne_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r3_0),
    kInstruction_rsb_ne_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r4_0),
    kInstruction_rsb_ne_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r5_0),
    kInstruction_rsb_ne_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r6_0),
    kInstruction_rsb_ne_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ne_r7_r7_0),
    kInstruction_rsb_ne_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r0_0),
    kInstruction_rsb_cs_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r1_0),
    kInstruction_rsb_cs_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r2_0),
    kInstruction_rsb_cs_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r3_0),
    kInstruction_rsb_cs_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r4_0),
    kInstruction_rsb_cs_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r5_0),
    kInstruction_rsb_cs_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r6_0),
    kInstruction_rsb_cs_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r0_r7_0),
    kInstruction_rsb_cs_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r0_0),
    kInstruction_rsb_cs_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r1_0),
    kInstruction_rsb_cs_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r2_0),
    kInstruction_rsb_cs_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r3_0),
    kInstruction_rsb_cs_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r4_0),
    kInstruction_rsb_cs_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r5_0),
    kInstruction_rsb_cs_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r6_0),
    kInstruction_rsb_cs_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r1_r7_0),
    kInstruction_rsb_cs_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r0_0),
    kInstruction_rsb_cs_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r1_0),
    kInstruction_rsb_cs_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r2_0),
    kInstruction_rsb_cs_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r3_0),
    kInstruction_rsb_cs_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r4_0),
    kInstruction_rsb_cs_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r5_0),
    kInstruction_rsb_cs_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r6_0),
    kInstruction_rsb_cs_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r2_r7_0),
    kInstruction_rsb_cs_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r0_0),
    kInstruction_rsb_cs_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r1_0),
    kInstruction_rsb_cs_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r2_0),
    kInstruction_rsb_cs_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r3_0),
    kInstruction_rsb_cs_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r4_0),
    kInstruction_rsb_cs_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r5_0),
    kInstruction_rsb_cs_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r6_0),
    kInstruction_rsb_cs_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r3_r7_0),
    kInstruction_rsb_cs_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r0_0),
    kInstruction_rsb_cs_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r1_0),
    kInstruction_rsb_cs_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r2_0),
    kInstruction_rsb_cs_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r3_0),
    kInstruction_rsb_cs_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r4_0),
    kInstruction_rsb_cs_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r5_0),
    kInstruction_rsb_cs_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r6_0),
    kInstruction_rsb_cs_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r4_r7_0),
    kInstruction_rsb_cs_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r0_0),
    kInstruction_rsb_cs_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r1_0),
    kInstruction_rsb_cs_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r2_0),
    kInstruction_rsb_cs_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r3_0),
    kInstruction_rsb_cs_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r4_0),
    kInstruction_rsb_cs_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r5_0),
    kInstruction_rsb_cs_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r6_0),
    kInstruction_rsb_cs_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r5_r7_0),
    kInstruction_rsb_cs_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r0_0),
    kInstruction_rsb_cs_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r1_0),
    kInstruction_rsb_cs_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r2_0),
    kInstruction_rsb_cs_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r3_0),
    kInstruction_rsb_cs_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r4_0),
    kInstruction_rsb_cs_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r5_0),
    kInstruction_rsb_cs_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r6_0),
    kInstruction_rsb_cs_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r6_r7_0),
    kInstruction_rsb_cs_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r0_0),
    kInstruction_rsb_cs_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r1_0),
    kInstruction_rsb_cs_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r2_0),
    kInstruction_rsb_cs_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r3_0),
    kInstruction_rsb_cs_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r4_0),
    kInstruction_rsb_cs_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r5_0),
    kInstruction_rsb_cs_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r6_0),
    kInstruction_rsb_cs_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cs_r7_r7_0),
    kInstruction_rsb_cs_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r0_0),
    kInstruction_rsb_cc_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r1_0),
    kInstruction_rsb_cc_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r2_0),
    kInstruction_rsb_cc_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r3_0),
    kInstruction_rsb_cc_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r4_0),
    kInstruction_rsb_cc_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r5_0),
    kInstruction_rsb_cc_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r6_0),
    kInstruction_rsb_cc_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r0_r7_0),
    kInstruction_rsb_cc_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r0_0),
    kInstruction_rsb_cc_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r1_0),
    kInstruction_rsb_cc_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r2_0),
    kInstruction_rsb_cc_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r3_0),
    kInstruction_rsb_cc_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r4_0),
    kInstruction_rsb_cc_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r5_0),
    kInstruction_rsb_cc_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r6_0),
    kInstruction_rsb_cc_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r1_r7_0),
    kInstruction_rsb_cc_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r0_0),
    kInstruction_rsb_cc_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r1_0),
    kInstruction_rsb_cc_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r2_0),
    kInstruction_rsb_cc_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r3_0),
    kInstruction_rsb_cc_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r4_0),
    kInstruction_rsb_cc_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r5_0),
    kInstruction_rsb_cc_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r6_0),
    kInstruction_rsb_cc_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r2_r7_0),
    kInstruction_rsb_cc_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r0_0),
    kInstruction_rsb_cc_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r1_0),
    kInstruction_rsb_cc_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r2_0),
    kInstruction_rsb_cc_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r3_0),
    kInstruction_rsb_cc_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r4_0),
    kInstruction_rsb_cc_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r5_0),
    kInstruction_rsb_cc_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r6_0),
    kInstruction_rsb_cc_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r3_r7_0),
    kInstruction_rsb_cc_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r0_0),
    kInstruction_rsb_cc_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r1_0),
    kInstruction_rsb_cc_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r2_0),
    kInstruction_rsb_cc_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r3_0),
    kInstruction_rsb_cc_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r4_0),
    kInstruction_rsb_cc_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r5_0),
    kInstruction_rsb_cc_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r6_0),
    kInstruction_rsb_cc_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r4_r7_0),
    kInstruction_rsb_cc_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r0_0),
    kInstruction_rsb_cc_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r1_0),
    kInstruction_rsb_cc_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r2_0),
    kInstruction_rsb_cc_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r3_0),
    kInstruction_rsb_cc_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r4_0),
    kInstruction_rsb_cc_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r5_0),
    kInstruction_rsb_cc_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r6_0),
    kInstruction_rsb_cc_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r5_r7_0),
    kInstruction_rsb_cc_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r0_0),
    kInstruction_rsb_cc_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r1_0),
    kInstruction_rsb_cc_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r2_0),
    kInstruction_rsb_cc_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r3_0),
    kInstruction_rsb_cc_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r4_0),
    kInstruction_rsb_cc_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r5_0),
    kInstruction_rsb_cc_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r6_0),
    kInstruction_rsb_cc_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r6_r7_0),
    kInstruction_rsb_cc_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r0_0),
    kInstruction_rsb_cc_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r1_0),
    kInstruction_rsb_cc_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r2_0),
    kInstruction_rsb_cc_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r3_0),
    kInstruction_rsb_cc_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r4_0),
    kInstruction_rsb_cc_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r5_0),
    kInstruction_rsb_cc_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r6_0),
    kInstruction_rsb_cc_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_cc_r7_r7_0),
    kInstruction_rsb_cc_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r0_0),
    kInstruction_rsb_mi_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r1_0),
    kInstruction_rsb_mi_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r2_0),
    kInstruction_rsb_mi_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r3_0),
    kInstruction_rsb_mi_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r4_0),
    kInstruction_rsb_mi_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r5_0),
    kInstruction_rsb_mi_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r6_0),
    kInstruction_rsb_mi_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r0_r7_0),
    kInstruction_rsb_mi_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r0_0),
    kInstruction_rsb_mi_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r1_0),
    kInstruction_rsb_mi_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r2_0),
    kInstruction_rsb_mi_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r3_0),
    kInstruction_rsb_mi_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r4_0),
    kInstruction_rsb_mi_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r5_0),
    kInstruction_rsb_mi_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r6_0),
    kInstruction_rsb_mi_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r1_r7_0),
    kInstruction_rsb_mi_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r0_0),
    kInstruction_rsb_mi_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r1_0),
    kInstruction_rsb_mi_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r2_0),
    kInstruction_rsb_mi_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r3_0),
    kInstruction_rsb_mi_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r4_0),
    kInstruction_rsb_mi_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r5_0),
    kInstruction_rsb_mi_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r6_0),
    kInstruction_rsb_mi_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r2_r7_0),
    kInstruction_rsb_mi_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r0_0),
    kInstruction_rsb_mi_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r1_0),
    kInstruction_rsb_mi_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r2_0),
    kInstruction_rsb_mi_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r3_0),
    kInstruction_rsb_mi_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r4_0),
    kInstruction_rsb_mi_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r5_0),
    kInstruction_rsb_mi_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r6_0),
    kInstruction_rsb_mi_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r3_r7_0),
    kInstruction_rsb_mi_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r0_0),
    kInstruction_rsb_mi_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r1_0),
    kInstruction_rsb_mi_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r2_0),
    kInstruction_rsb_mi_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r3_0),
    kInstruction_rsb_mi_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r4_0),
    kInstruction_rsb_mi_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r5_0),
    kInstruction_rsb_mi_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r6_0),
    kInstruction_rsb_mi_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r4_r7_0),
    kInstruction_rsb_mi_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r0_0),
    kInstruction_rsb_mi_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r1_0),
    kInstruction_rsb_mi_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r2_0),
    kInstruction_rsb_mi_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r3_0),
    kInstruction_rsb_mi_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r4_0),
    kInstruction_rsb_mi_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r5_0),
    kInstruction_rsb_mi_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r6_0),
    kInstruction_rsb_mi_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r5_r7_0),
    kInstruction_rsb_mi_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r0_0),
    kInstruction_rsb_mi_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r1_0),
    kInstruction_rsb_mi_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r2_0),
    kInstruction_rsb_mi_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r3_0),
    kInstruction_rsb_mi_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r4_0),
    kInstruction_rsb_mi_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r5_0),
    kInstruction_rsb_mi_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r6_0),
    kInstruction_rsb_mi_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r6_r7_0),
    kInstruction_rsb_mi_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r0_0),
    kInstruction_rsb_mi_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r1_0),
    kInstruction_rsb_mi_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r2_0),
    kInstruction_rsb_mi_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r3_0),
    kInstruction_rsb_mi_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r4_0),
    kInstruction_rsb_mi_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r5_0),
    kInstruction_rsb_mi_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r6_0),
    kInstruction_rsb_mi_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_mi_r7_r7_0),
    kInstruction_rsb_mi_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r0_0),
    kInstruction_rsb_pl_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r1_0),
    kInstruction_rsb_pl_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r2_0),
    kInstruction_rsb_pl_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r3_0),
    kInstruction_rsb_pl_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r4_0),
    kInstruction_rsb_pl_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r5_0),
    kInstruction_rsb_pl_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r6_0),
    kInstruction_rsb_pl_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r0_r7_0),
    kInstruction_rsb_pl_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r0_0),
    kInstruction_rsb_pl_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r1_0),
    kInstruction_rsb_pl_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r2_0),
    kInstruction_rsb_pl_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r3_0),
    kInstruction_rsb_pl_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r4_0),
    kInstruction_rsb_pl_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r5_0),
    kInstruction_rsb_pl_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r6_0),
    kInstruction_rsb_pl_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r1_r7_0),
    kInstruction_rsb_pl_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r0_0),
    kInstruction_rsb_pl_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r1_0),
    kInstruction_rsb_pl_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r2_0),
    kInstruction_rsb_pl_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r3_0),
    kInstruction_rsb_pl_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r4_0),
    kInstruction_rsb_pl_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r5_0),
    kInstruction_rsb_pl_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r6_0),
    kInstruction_rsb_pl_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r2_r7_0),
    kInstruction_rsb_pl_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r0_0),
    kInstruction_rsb_pl_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r1_0),
    kInstruction_rsb_pl_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r2_0),
    kInstruction_rsb_pl_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r3_0),
    kInstruction_rsb_pl_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r4_0),
    kInstruction_rsb_pl_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r5_0),
    kInstruction_rsb_pl_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r6_0),
    kInstruction_rsb_pl_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r3_r7_0),
    kInstruction_rsb_pl_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r0_0),
    kInstruction_rsb_pl_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r1_0),
    kInstruction_rsb_pl_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r2_0),
    kInstruction_rsb_pl_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r3_0),
    kInstruction_rsb_pl_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r4_0),
    kInstruction_rsb_pl_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r5_0),
    kInstruction_rsb_pl_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r6_0),
    kInstruction_rsb_pl_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r4_r7_0),
    kInstruction_rsb_pl_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r0_0),
    kInstruction_rsb_pl_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r1_0),
    kInstruction_rsb_pl_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r2_0),
    kInstruction_rsb_pl_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r3_0),
    kInstruction_rsb_pl_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r4_0),
    kInstruction_rsb_pl_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r5_0),
    kInstruction_rsb_pl_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r6_0),
    kInstruction_rsb_pl_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r5_r7_0),
    kInstruction_rsb_pl_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r0_0),
    kInstruction_rsb_pl_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r1_0),
    kInstruction_rsb_pl_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r2_0),
    kInstruction_rsb_pl_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r3_0),
    kInstruction_rsb_pl_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r4_0),
    kInstruction_rsb_pl_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r5_0),
    kInstruction_rsb_pl_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r6_0),
    kInstruction_rsb_pl_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r6_r7_0),
    kInstruction_rsb_pl_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r0_0),
    kInstruction_rsb_pl_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r1_0),
    kInstruction_rsb_pl_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r2_0),
    kInstruction_rsb_pl_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r3_0),
    kInstruction_rsb_pl_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r4_0),
    kInstruction_rsb_pl_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r5_0),
    kInstruction_rsb_pl_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r6_0),
    kInstruction_rsb_pl_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_pl_r7_r7_0),
    kInstruction_rsb_pl_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r0_0),
    kInstruction_rsb_vs_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r1_0),
    kInstruction_rsb_vs_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r2_0),
    kInstruction_rsb_vs_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r3_0),
    kInstruction_rsb_vs_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r4_0),
    kInstruction_rsb_vs_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r5_0),
    kInstruction_rsb_vs_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r6_0),
    kInstruction_rsb_vs_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r0_r7_0),
    kInstruction_rsb_vs_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r0_0),
    kInstruction_rsb_vs_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r1_0),
    kInstruction_rsb_vs_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r2_0),
    kInstruction_rsb_vs_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r3_0),
    kInstruction_rsb_vs_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r4_0),
    kInstruction_rsb_vs_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r5_0),
    kInstruction_rsb_vs_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r6_0),
    kInstruction_rsb_vs_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r1_r7_0),
    kInstruction_rsb_vs_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r0_0),
    kInstruction_rsb_vs_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r1_0),
    kInstruction_rsb_vs_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r2_0),
    kInstruction_rsb_vs_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r3_0),
    kInstruction_rsb_vs_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r4_0),
    kInstruction_rsb_vs_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r5_0),
    kInstruction_rsb_vs_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r6_0),
    kInstruction_rsb_vs_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r2_r7_0),
    kInstruction_rsb_vs_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r0_0),
    kInstruction_rsb_vs_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r1_0),
    kInstruction_rsb_vs_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r2_0),
    kInstruction_rsb_vs_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r3_0),
    kInstruction_rsb_vs_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r4_0),
    kInstruction_rsb_vs_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r5_0),
    kInstruction_rsb_vs_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r6_0),
    kInstruction_rsb_vs_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r3_r7_0),
    kInstruction_rsb_vs_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r0_0),
    kInstruction_rsb_vs_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r1_0),
    kInstruction_rsb_vs_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r2_0),
    kInstruction_rsb_vs_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r3_0),
    kInstruction_rsb_vs_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r4_0),
    kInstruction_rsb_vs_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r5_0),
    kInstruction_rsb_vs_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r6_0),
    kInstruction_rsb_vs_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r4_r7_0),
    kInstruction_rsb_vs_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r0_0),
    kInstruction_rsb_vs_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r1_0),
    kInstruction_rsb_vs_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r2_0),
    kInstruction_rsb_vs_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r3_0),
    kInstruction_rsb_vs_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r4_0),
    kInstruction_rsb_vs_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r5_0),
    kInstruction_rsb_vs_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r6_0),
    kInstruction_rsb_vs_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r5_r7_0),
    kInstruction_rsb_vs_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r0_0),
    kInstruction_rsb_vs_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r1_0),
    kInstruction_rsb_vs_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r2_0),
    kInstruction_rsb_vs_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r3_0),
    kInstruction_rsb_vs_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r4_0),
    kInstruction_rsb_vs_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r5_0),
    kInstruction_rsb_vs_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r6_0),
    kInstruction_rsb_vs_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r6_r7_0),
    kInstruction_rsb_vs_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r0_0),
    kInstruction_rsb_vs_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r1_0),
    kInstruction_rsb_vs_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r2_0),
    kInstruction_rsb_vs_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r3_0),
    kInstruction_rsb_vs_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r4_0),
    kInstruction_rsb_vs_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r5_0),
    kInstruction_rsb_vs_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r6_0),
    kInstruction_rsb_vs_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vs_r7_r7_0),
    kInstruction_rsb_vs_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r0_0),
    kInstruction_rsb_vc_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r1_0),
    kInstruction_rsb_vc_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r2_0),
    kInstruction_rsb_vc_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r3_0),
    kInstruction_rsb_vc_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r4_0),
    kInstruction_rsb_vc_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r5_0),
    kInstruction_rsb_vc_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r6_0),
    kInstruction_rsb_vc_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r0_r7_0),
    kInstruction_rsb_vc_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r0_0),
    kInstruction_rsb_vc_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r1_0),
    kInstruction_rsb_vc_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r2_0),
    kInstruction_rsb_vc_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r3_0),
    kInstruction_rsb_vc_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r4_0),
    kInstruction_rsb_vc_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r5_0),
    kInstruction_rsb_vc_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r6_0),
    kInstruction_rsb_vc_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r1_r7_0),
    kInstruction_rsb_vc_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r0_0),
    kInstruction_rsb_vc_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r1_0),
    kInstruction_rsb_vc_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r2_0),
    kInstruction_rsb_vc_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r3_0),
    kInstruction_rsb_vc_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r4_0),
    kInstruction_rsb_vc_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r5_0),
    kInstruction_rsb_vc_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r6_0),
    kInstruction_rsb_vc_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r2_r7_0),
    kInstruction_rsb_vc_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r0_0),
    kInstruction_rsb_vc_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r1_0),
    kInstruction_rsb_vc_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r2_0),
    kInstruction_rsb_vc_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r3_0),
    kInstruction_rsb_vc_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r4_0),
    kInstruction_rsb_vc_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r5_0),
    kInstruction_rsb_vc_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r6_0),
    kInstruction_rsb_vc_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r3_r7_0),
    kInstruction_rsb_vc_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r0_0),
    kInstruction_rsb_vc_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r1_0),
    kInstruction_rsb_vc_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r2_0),
    kInstruction_rsb_vc_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r3_0),
    kInstruction_rsb_vc_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r4_0),
    kInstruction_rsb_vc_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r5_0),
    kInstruction_rsb_vc_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r6_0),
    kInstruction_rsb_vc_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r4_r7_0),
    kInstruction_rsb_vc_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r0_0),
    kInstruction_rsb_vc_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r1_0),
    kInstruction_rsb_vc_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r2_0),
    kInstruction_rsb_vc_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r3_0),
    kInstruction_rsb_vc_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r4_0),
    kInstruction_rsb_vc_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r5_0),
    kInstruction_rsb_vc_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r6_0),
    kInstruction_rsb_vc_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r5_r7_0),
    kInstruction_rsb_vc_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r0_0),
    kInstruction_rsb_vc_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r1_0),
    kInstruction_rsb_vc_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r2_0),
    kInstruction_rsb_vc_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r3_0),
    kInstruction_rsb_vc_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r4_0),
    kInstruction_rsb_vc_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r5_0),
    kInstruction_rsb_vc_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r6_0),
    kInstruction_rsb_vc_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r6_r7_0),
    kInstruction_rsb_vc_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r0_0),
    kInstruction_rsb_vc_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r1_0),
    kInstruction_rsb_vc_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r2_0),
    kInstruction_rsb_vc_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r3_0),
    kInstruction_rsb_vc_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r4_0),
    kInstruction_rsb_vc_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r5_0),
    kInstruction_rsb_vc_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r6_0),
    kInstruction_rsb_vc_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_vc_r7_r7_0),
    kInstruction_rsb_vc_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r0_0),
    kInstruction_rsb_hi_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r1_0),
    kInstruction_rsb_hi_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r2_0),
    kInstruction_rsb_hi_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r3_0),
    kInstruction_rsb_hi_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r4_0),
    kInstruction_rsb_hi_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r5_0),
    kInstruction_rsb_hi_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r6_0),
    kInstruction_rsb_hi_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r0_r7_0),
    kInstruction_rsb_hi_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r0_0),
    kInstruction_rsb_hi_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r1_0),
    kInstruction_rsb_hi_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r2_0),
    kInstruction_rsb_hi_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r3_0),
    kInstruction_rsb_hi_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r4_0),
    kInstruction_rsb_hi_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r5_0),
    kInstruction_rsb_hi_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r6_0),
    kInstruction_rsb_hi_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r1_r7_0),
    kInstruction_rsb_hi_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r0_0),
    kInstruction_rsb_hi_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r1_0),
    kInstruction_rsb_hi_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r2_0),
    kInstruction_rsb_hi_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r3_0),
    kInstruction_rsb_hi_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r4_0),
    kInstruction_rsb_hi_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r5_0),
    kInstruction_rsb_hi_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r6_0),
    kInstruction_rsb_hi_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r2_r7_0),
    kInstruction_rsb_hi_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r0_0),
    kInstruction_rsb_hi_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r1_0),
    kInstruction_rsb_hi_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r2_0),
    kInstruction_rsb_hi_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r3_0),
    kInstruction_rsb_hi_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r4_0),
    kInstruction_rsb_hi_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r5_0),
    kInstruction_rsb_hi_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r6_0),
    kInstruction_rsb_hi_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r3_r7_0),
    kInstruction_rsb_hi_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r0_0),
    kInstruction_rsb_hi_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r1_0),
    kInstruction_rsb_hi_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r2_0),
    kInstruction_rsb_hi_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r3_0),
    kInstruction_rsb_hi_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r4_0),
    kInstruction_rsb_hi_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r5_0),
    kInstruction_rsb_hi_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r6_0),
    kInstruction_rsb_hi_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r4_r7_0),
    kInstruction_rsb_hi_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r0_0),
    kInstruction_rsb_hi_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r1_0),
    kInstruction_rsb_hi_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r2_0),
    kInstruction_rsb_hi_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r3_0),
    kInstruction_rsb_hi_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r4_0),
    kInstruction_rsb_hi_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r5_0),
    kInstruction_rsb_hi_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r6_0),
    kInstruction_rsb_hi_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r5_r7_0),
    kInstruction_rsb_hi_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r0_0),
    kInstruction_rsb_hi_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r1_0),
    kInstruction_rsb_hi_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r2_0),
    kInstruction_rsb_hi_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r3_0),
    kInstruction_rsb_hi_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r4_0),
    kInstruction_rsb_hi_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r5_0),
    kInstruction_rsb_hi_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r6_0),
    kInstruction_rsb_hi_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r6_r7_0),
    kInstruction_rsb_hi_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r0_0),
    kInstruction_rsb_hi_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r1_0),
    kInstruction_rsb_hi_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r2_0),
    kInstruction_rsb_hi_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r3_0),
    kInstruction_rsb_hi_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r4_0),
    kInstruction_rsb_hi_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r5_0),
    kInstruction_rsb_hi_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r6_0),
    kInstruction_rsb_hi_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_hi_r7_r7_0),
    kInstruction_rsb_hi_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r0_0),
    kInstruction_rsb_ls_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r1_0),
    kInstruction_rsb_ls_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r2_0),
    kInstruction_rsb_ls_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r3_0),
    kInstruction_rsb_ls_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r4_0),
    kInstruction_rsb_ls_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r5_0),
    kInstruction_rsb_ls_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r6_0),
    kInstruction_rsb_ls_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r0_r7_0),
    kInstruction_rsb_ls_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r0_0),
    kInstruction_rsb_ls_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r1_0),
    kInstruction_rsb_ls_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r2_0),
    kInstruction_rsb_ls_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r3_0),
    kInstruction_rsb_ls_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r4_0),
    kInstruction_rsb_ls_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r5_0),
    kInstruction_rsb_ls_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r6_0),
    kInstruction_rsb_ls_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r1_r7_0),
    kInstruction_rsb_ls_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r0_0),
    kInstruction_rsb_ls_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r1_0),
    kInstruction_rsb_ls_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r2_0),
    kInstruction_rsb_ls_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r3_0),
    kInstruction_rsb_ls_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r4_0),
    kInstruction_rsb_ls_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r5_0),
    kInstruction_rsb_ls_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r6_0),
    kInstruction_rsb_ls_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r2_r7_0),
    kInstruction_rsb_ls_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r0_0),
    kInstruction_rsb_ls_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r1_0),
    kInstruction_rsb_ls_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r2_0),
    kInstruction_rsb_ls_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r3_0),
    kInstruction_rsb_ls_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r4_0),
    kInstruction_rsb_ls_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r5_0),
    kInstruction_rsb_ls_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r6_0),
    kInstruction_rsb_ls_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r3_r7_0),
    kInstruction_rsb_ls_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r0_0),
    kInstruction_rsb_ls_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r1_0),
    kInstruction_rsb_ls_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r2_0),
    kInstruction_rsb_ls_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r3_0),
    kInstruction_rsb_ls_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r4_0),
    kInstruction_rsb_ls_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r5_0),
    kInstruction_rsb_ls_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r6_0),
    kInstruction_rsb_ls_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r4_r7_0),
    kInstruction_rsb_ls_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r0_0),
    kInstruction_rsb_ls_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r1_0),
    kInstruction_rsb_ls_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r2_0),
    kInstruction_rsb_ls_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r3_0),
    kInstruction_rsb_ls_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r4_0),
    kInstruction_rsb_ls_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r5_0),
    kInstruction_rsb_ls_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r6_0),
    kInstruction_rsb_ls_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r5_r7_0),
    kInstruction_rsb_ls_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r0_0),
    kInstruction_rsb_ls_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r1_0),
    kInstruction_rsb_ls_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r2_0),
    kInstruction_rsb_ls_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r3_0),
    kInstruction_rsb_ls_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r4_0),
    kInstruction_rsb_ls_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r5_0),
    kInstruction_rsb_ls_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r6_0),
    kInstruction_rsb_ls_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r6_r7_0),
    kInstruction_rsb_ls_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r0_0),
    kInstruction_rsb_ls_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r1_0),
    kInstruction_rsb_ls_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r2_0),
    kInstruction_rsb_ls_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r3_0),
    kInstruction_rsb_ls_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r4_0),
    kInstruction_rsb_ls_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r5_0),
    kInstruction_rsb_ls_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r6_0),
    kInstruction_rsb_ls_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ls_r7_r7_0),
    kInstruction_rsb_ls_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r0_0),
    kInstruction_rsb_ge_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r1_0),
    kInstruction_rsb_ge_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r2_0),
    kInstruction_rsb_ge_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r3_0),
    kInstruction_rsb_ge_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r4_0),
    kInstruction_rsb_ge_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r5_0),
    kInstruction_rsb_ge_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r6_0),
    kInstruction_rsb_ge_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r0_r7_0),
    kInstruction_rsb_ge_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r0_0),
    kInstruction_rsb_ge_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r1_0),
    kInstruction_rsb_ge_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r2_0),
    kInstruction_rsb_ge_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r3_0),
    kInstruction_rsb_ge_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r4_0),
    kInstruction_rsb_ge_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r5_0),
    kInstruction_rsb_ge_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r6_0),
    kInstruction_rsb_ge_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r1_r7_0),
    kInstruction_rsb_ge_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r0_0),
    kInstruction_rsb_ge_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r1_0),
    kInstruction_rsb_ge_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r2_0),
    kInstruction_rsb_ge_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r3_0),
    kInstruction_rsb_ge_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r4_0),
    kInstruction_rsb_ge_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r5_0),
    kInstruction_rsb_ge_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r6_0),
    kInstruction_rsb_ge_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r2_r7_0),
    kInstruction_rsb_ge_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r0_0),
    kInstruction_rsb_ge_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r1_0),
    kInstruction_rsb_ge_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r2_0),
    kInstruction_rsb_ge_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r3_0),
    kInstruction_rsb_ge_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r4_0),
    kInstruction_rsb_ge_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r5_0),
    kInstruction_rsb_ge_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r6_0),
    kInstruction_rsb_ge_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r3_r7_0),
    kInstruction_rsb_ge_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r0_0),
    kInstruction_rsb_ge_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r1_0),
    kInstruction_rsb_ge_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r2_0),
    kInstruction_rsb_ge_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r3_0),
    kInstruction_rsb_ge_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r4_0),
    kInstruction_rsb_ge_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r5_0),
    kInstruction_rsb_ge_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r6_0),
    kInstruction_rsb_ge_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r4_r7_0),
    kInstruction_rsb_ge_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r0_0),
    kInstruction_rsb_ge_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r1_0),
    kInstruction_rsb_ge_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r2_0),
    kInstruction_rsb_ge_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r3_0),
    kInstruction_rsb_ge_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r4_0),
    kInstruction_rsb_ge_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r5_0),
    kInstruction_rsb_ge_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r6_0),
    kInstruction_rsb_ge_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r5_r7_0),
    kInstruction_rsb_ge_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r0_0),
    kInstruction_rsb_ge_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r1_0),
    kInstruction_rsb_ge_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r2_0),
    kInstruction_rsb_ge_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r3_0),
    kInstruction_rsb_ge_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r4_0),
    kInstruction_rsb_ge_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r5_0),
    kInstruction_rsb_ge_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r6_0),
    kInstruction_rsb_ge_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r6_r7_0),
    kInstruction_rsb_ge_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r0_0),
    kInstruction_rsb_ge_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r1_0),
    kInstruction_rsb_ge_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r2_0),
    kInstruction_rsb_ge_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r3_0),
    kInstruction_rsb_ge_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r4_0),
    kInstruction_rsb_ge_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r5_0),
    kInstruction_rsb_ge_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r6_0),
    kInstruction_rsb_ge_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_ge_r7_r7_0),
    kInstruction_rsb_ge_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r0_0),
    kInstruction_rsb_lt_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r1_0),
    kInstruction_rsb_lt_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r2_0),
    kInstruction_rsb_lt_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r3_0),
    kInstruction_rsb_lt_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r4_0),
    kInstruction_rsb_lt_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r5_0),
    kInstruction_rsb_lt_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r6_0),
    kInstruction_rsb_lt_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r0_r7_0),
    kInstruction_rsb_lt_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r0_0),
    kInstruction_rsb_lt_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r1_0),
    kInstruction_rsb_lt_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r2_0),
    kInstruction_rsb_lt_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r3_0),
    kInstruction_rsb_lt_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r4_0),
    kInstruction_rsb_lt_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r5_0),
    kInstruction_rsb_lt_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r6_0),
    kInstruction_rsb_lt_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r1_r7_0),
    kInstruction_rsb_lt_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r0_0),
    kInstruction_rsb_lt_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r1_0),
    kInstruction_rsb_lt_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r2_0),
    kInstruction_rsb_lt_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r3_0),
    kInstruction_rsb_lt_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r4_0),
    kInstruction_rsb_lt_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r5_0),
    kInstruction_rsb_lt_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r6_0),
    kInstruction_rsb_lt_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r2_r7_0),
    kInstruction_rsb_lt_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r0_0),
    kInstruction_rsb_lt_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r1_0),
    kInstruction_rsb_lt_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r2_0),
    kInstruction_rsb_lt_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r3_0),
    kInstruction_rsb_lt_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r4_0),
    kInstruction_rsb_lt_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r5_0),
    kInstruction_rsb_lt_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r6_0),
    kInstruction_rsb_lt_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r3_r7_0),
    kInstruction_rsb_lt_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r0_0),
    kInstruction_rsb_lt_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r1_0),
    kInstruction_rsb_lt_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r2_0),
    kInstruction_rsb_lt_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r3_0),
    kInstruction_rsb_lt_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r4_0),
    kInstruction_rsb_lt_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r5_0),
    kInstruction_rsb_lt_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r6_0),
    kInstruction_rsb_lt_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r4_r7_0),
    kInstruction_rsb_lt_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r0_0),
    kInstruction_rsb_lt_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r1_0),
    kInstruction_rsb_lt_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r2_0),
    kInstruction_rsb_lt_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r3_0),
    kInstruction_rsb_lt_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r4_0),
    kInstruction_rsb_lt_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r5_0),
    kInstruction_rsb_lt_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r6_0),
    kInstruction_rsb_lt_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r5_r7_0),
    kInstruction_rsb_lt_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r0_0),
    kInstruction_rsb_lt_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r1_0),
    kInstruction_rsb_lt_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r2_0),
    kInstruction_rsb_lt_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r3_0),
    kInstruction_rsb_lt_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r4_0),
    kInstruction_rsb_lt_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r5_0),
    kInstruction_rsb_lt_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r6_0),
    kInstruction_rsb_lt_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r6_r7_0),
    kInstruction_rsb_lt_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r0_0),
    kInstruction_rsb_lt_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r1_0),
    kInstruction_rsb_lt_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r2_0),
    kInstruction_rsb_lt_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r3_0),
    kInstruction_rsb_lt_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r4_0),
    kInstruction_rsb_lt_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r5_0),
    kInstruction_rsb_lt_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r6_0),
    kInstruction_rsb_lt_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_lt_r7_r7_0),
    kInstruction_rsb_lt_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r0_0),
    kInstruction_rsb_gt_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r1_0),
    kInstruction_rsb_gt_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r2_0),
    kInstruction_rsb_gt_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r3_0),
    kInstruction_rsb_gt_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r4_0),
    kInstruction_rsb_gt_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r5_0),
    kInstruction_rsb_gt_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r6_0),
    kInstruction_rsb_gt_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r0_r7_0),
    kInstruction_rsb_gt_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r0_0),
    kInstruction_rsb_gt_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r1_0),
    kInstruction_rsb_gt_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r2_0),
    kInstruction_rsb_gt_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r3_0),
    kInstruction_rsb_gt_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r4_0),
    kInstruction_rsb_gt_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r5_0),
    kInstruction_rsb_gt_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r6_0),
    kInstruction_rsb_gt_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r1_r7_0),
    kInstruction_rsb_gt_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r0_0),
    kInstruction_rsb_gt_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r1_0),
    kInstruction_rsb_gt_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r2_0),
    kInstruction_rsb_gt_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r3_0),
    kInstruction_rsb_gt_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r4_0),
    kInstruction_rsb_gt_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r5_0),
    kInstruction_rsb_gt_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r6_0),
    kInstruction_rsb_gt_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r2_r7_0),
    kInstruction_rsb_gt_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r0_0),
    kInstruction_rsb_gt_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r1_0),
    kInstruction_rsb_gt_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r2_0),
    kInstruction_rsb_gt_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r3_0),
    kInstruction_rsb_gt_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r4_0),
    kInstruction_rsb_gt_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r5_0),
    kInstruction_rsb_gt_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r6_0),
    kInstruction_rsb_gt_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r3_r7_0),
    kInstruction_rsb_gt_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r0_0),
    kInstruction_rsb_gt_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r1_0),
    kInstruction_rsb_gt_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r2_0),
    kInstruction_rsb_gt_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r3_0),
    kInstruction_rsb_gt_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r4_0),
    kInstruction_rsb_gt_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r5_0),
    kInstruction_rsb_gt_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r6_0),
    kInstruction_rsb_gt_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r4_r7_0),
    kInstruction_rsb_gt_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r0_0),
    kInstruction_rsb_gt_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r1_0),
    kInstruction_rsb_gt_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r2_0),
    kInstruction_rsb_gt_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r3_0),
    kInstruction_rsb_gt_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r4_0),
    kInstruction_rsb_gt_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r5_0),
    kInstruction_rsb_gt_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r6_0),
    kInstruction_rsb_gt_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r5_r7_0),
    kInstruction_rsb_gt_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r0_0),
    kInstruction_rsb_gt_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r1_0),
    kInstruction_rsb_gt_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r2_0),
    kInstruction_rsb_gt_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r3_0),
    kInstruction_rsb_gt_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r4_0),
    kInstruction_rsb_gt_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r5_0),
    kInstruction_rsb_gt_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r6_0),
    kInstruction_rsb_gt_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r6_r7_0),
    kInstruction_rsb_gt_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r0_0),
    kInstruction_rsb_gt_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r1_0),
    kInstruction_rsb_gt_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r2_0),
    kInstruction_rsb_gt_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r3_0),
    kInstruction_rsb_gt_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r4_0),
    kInstruction_rsb_gt_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r5_0),
    kInstruction_rsb_gt_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r6_0),
    kInstruction_rsb_gt_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_gt_r7_r7_0),
    kInstruction_rsb_gt_r7_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r0_0),
    kInstruction_rsb_le_r0_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r1_0),
    kInstruction_rsb_le_r0_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r2_0),
    kInstruction_rsb_le_r0_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r3_0),
    kInstruction_rsb_le_r0_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r4_0),
    kInstruction_rsb_le_r0_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r5_0),
    kInstruction_rsb_le_r0_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r6_0),
    kInstruction_rsb_le_r0_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r0_r7_0),
    kInstruction_rsb_le_r0_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r0_0),
    kInstruction_rsb_le_r1_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r1_0),
    kInstruction_rsb_le_r1_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r2_0),
    kInstruction_rsb_le_r1_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r3_0),
    kInstruction_rsb_le_r1_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r4_0),
    kInstruction_rsb_le_r1_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r5_0),
    kInstruction_rsb_le_r1_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r6_0),
    kInstruction_rsb_le_r1_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r1_r7_0),
    kInstruction_rsb_le_r1_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r0_0),
    kInstruction_rsb_le_r2_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r1_0),
    kInstruction_rsb_le_r2_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r2_0),
    kInstruction_rsb_le_r2_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r3_0),
    kInstruction_rsb_le_r2_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r4_0),
    kInstruction_rsb_le_r2_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r5_0),
    kInstruction_rsb_le_r2_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r6_0),
    kInstruction_rsb_le_r2_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r2_r7_0),
    kInstruction_rsb_le_r2_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r0_0),
    kInstruction_rsb_le_r3_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r1_0),
    kInstruction_rsb_le_r3_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r2_0),
    kInstruction_rsb_le_r3_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r3_0),
    kInstruction_rsb_le_r3_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r4_0),
    kInstruction_rsb_le_r3_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r5_0),
    kInstruction_rsb_le_r3_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r6_0),
    kInstruction_rsb_le_r3_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r3_r7_0),
    kInstruction_rsb_le_r3_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r0_0),
    kInstruction_rsb_le_r4_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r1_0),
    kInstruction_rsb_le_r4_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r2_0),
    kInstruction_rsb_le_r4_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r3_0),
    kInstruction_rsb_le_r4_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r4_0),
    kInstruction_rsb_le_r4_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r5_0),
    kInstruction_rsb_le_r4_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r6_0),
    kInstruction_rsb_le_r4_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r4_r7_0),
    kInstruction_rsb_le_r4_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r0_0),
    kInstruction_rsb_le_r5_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r1_0),
    kInstruction_rsb_le_r5_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r2_0),
    kInstruction_rsb_le_r5_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r3_0),
    kInstruction_rsb_le_r5_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r4_0),
    kInstruction_rsb_le_r5_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r5_0),
    kInstruction_rsb_le_r5_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r6_0),
    kInstruction_rsb_le_r5_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r5_r7_0),
    kInstruction_rsb_le_r5_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r0_0),
    kInstruction_rsb_le_r6_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r1_0),
    kInstruction_rsb_le_r6_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r2_0),
    kInstruction_rsb_le_r6_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r3_0),
    kInstruction_rsb_le_r6_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r4_0),
    kInstruction_rsb_le_r6_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r5_0),
    kInstruction_rsb_le_r6_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r6_0),
    kInstruction_rsb_le_r6_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r6_r7_0),
    kInstruction_rsb_le_r6_r7_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r0_0),
    kInstruction_rsb_le_r7_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r1_0),
    kInstruction_rsb_le_r7_r1_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r2_0),
    kInstruction_rsb_le_r7_r2_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r3_0),
    kInstruction_rsb_le_r7_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r4_0),
    kInstruction_rsb_le_r7_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r5_0),
    kInstruction_rsb_le_r7_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r6_0),
    kInstruction_rsb_le_r7_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_rsb_le_r7_r7_0),
    kInstruction_rsb_le_r7_r7_0,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RDLOW_RNLOW_OPERAND_IMMEDIATE_ZERO_IN_IT_BLOCK_RSB_T32_H_
